searchData={"items":[{"type":"module","title":"Doggo","doc":"This module only contains miscellaneous functions.\n\nThe components are defined in `Doggo.Components`.","ref":"Doggo.html"},{"type":"function","title":"Doggo.hide_modal/2","doc":"Hides the modal with the given ID.","ref":"Doggo.html#hide_modal/2"},{"type":"function","title":"Example - Doggo.hide_modal/2","doc":"```heex\n<.link phx-click={hide_modal(\"pet-modal\")}>hide</.link>\n```","ref":"Doggo.html#hide_modal/2-example"},{"type":"function","title":"Doggo.modifier_class_name/2","doc":"Takes a modifier attribute name and value and returns a CSS class name.\n\nThis function is used as a default for the `class_name_fun` option.","ref":"Doggo.html#modifier_class_name/2"},{"type":"function","title":"Example - Doggo.modifier_class_name/2","doc":"iex> modifier_class_name(:size, \"large\")\n    \"is-large\"","ref":"Doggo.html#modifier_class_name/2-example"},{"type":"function","title":"Doggo.modifier_classes/1","doc":"Returns all modifier classes defined in the given components module.","ref":"Doggo.html#modifier_classes/1"},{"type":"function","title":"Usage - Doggo.modifier_classes/1","doc":"iex> modifier_classes(MyAppWeb.CoreComponents)\n    [\n      \"is-large\",\n      \"is-medium\",\n      \"is-primary\",\n      \"is-secondary\",\n      \"is-small\"\n    ]","ref":"Doggo.html#modifier_classes/1-usage"},{"type":"function","title":"Doggo.show_modal/2","doc":"Shows the modal with the given ID.","ref":"Doggo.html#show_modal/2"},{"type":"function","title":"Example - Doggo.show_modal/2","doc":"```heex\n<.link phx-click={show_modal(\"pet-modal\")}>show</.link>\n```","ref":"Doggo.html#show_modal/2-example"},{"type":"function","title":"Doggo.show_tab/3","doc":"Shows the tab with the given index of the `tabs/1` component with the given\nID.","ref":"Doggo.html#show_tab/3"},{"type":"function","title":"Example - Doggo.show_tab/3","doc":"Doggo.show_tab(\"my-tabs\", 2)","ref":"Doggo.html#show_tab/3-example"},{"type":"module","title":"Doggo.Components","doc":"This module defines macros that generate customized components.","ref":"Doggo.Components.html"},{"type":"module","title":"Usage - Doggo.Components","doc":"Add `use Doggo.Components` to your module and ensure you also add\n`use Phoenix.Component`. Then use the macros in this module to generate the\ncomponents you need.\n\n> #### `use Doggo.Components` {: .info}\n>\n> When you `use Doggo.Components`, the module will import `Doggo.Components`\n> and define a `__dog_components__/1` function that returns a map containing\n> the options of the Doggo components you used.\n\nTo generate all components with their default options:\n\n    defmodule MyAppWeb.CoreComponents do\n      use Doggo.Components\n      use Phoenix.Component\n\n      build_accordion()\n      build_action_bar()\n      build_alert()\n      build_alert_dialog()\n      build_app_bar()\n      build_avatar()\n      build_badge()\n      build_bottom_navigation()\n      build_box()\n      build_breadcrumb()\n      build_button()\n      build_button_link()\n      build_callout()\n      build_card()\n      build_carousel()\n      build_cluster()\n      build_combobox()\n      build_date()\n      build_datetime()\n      build_disclosure_button()\n      build_drawer()\n      build_fab()\n      build_fallback()\n      build_field_description()\n      build_field_errors()\n      build_field_group()\n      build_frame()\n      build_icon()\n      build_icon_sprite()\n      build_image()\n      build_label()\n      build_menu()\n      build_menu_bar()\n      build_menu_button()\n      build_menu_group()\n      build_menu_item()\n      build_menu_item_checkbox()\n      build_menu_item_radio_group()\n      build_modal()\n      build_navbar()\n      build_navbar_items()\n      build_page_header()\n      build_property_list()\n      build_radio_group()\n      build_skeleton()\n      build_split_pane()\n      build_stack()\n      build_steps()\n      build_switch()\n      build_tab_navigation()\n      build_table()\n      build_tabs()\n      build_tag()\n      build_time()\n      build_toggle_button()\n      build_toolbar()\n      build_tooltip()\n      build_tree()\n      build_tree_item()\n      build_vertical_nav()\n      build_vertical_nav_nested()\n      build_vertical_nav_section()\n    end","ref":"Doggo.Components.html#module-usage"},{"type":"module","title":"Common Options - Doggo.Components","doc":"All component macros support the following options:\n\n- `name` - The name of the function of the generated component. Defaults to\n  the macro name.\n- `base_class` - The base class used on the root element of the component. If\n  not set, a default base class is used.\n- `modifiers` - A keyword list of modifier attributes. For each item, an\n  attribute with the type `:string` is added. The options will be passed to\n  `Phoenix.Component.attr/3`. Most components define a set of default\n  modifiers that can be overridden.\n- `class_name_fun` - A 2-arity function that takes a modifier attribute name\n  and a value and returns a CSS class name. Defaults to\n  `Doggo.modifier_class_name/2`.\n\nSome components have additional options that are mostly used to allow the\ncustomization of certain class names or to set the Gettext module.","ref":"Doggo.Components.html#module-common-options"},{"type":"macro","title":"Doggo.Components.build_accordion/1","doc":"Renders a set of headings that control the visibility of their content\nsections.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_accordion/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_accordion/1","doc":"Generate component with default options:\n\n    build_accordion()","ref":"Doggo.Components.html#build_accordion/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_accordion/1","doc":"```elixir\n[\n  name: :accordion,\n  base_class: \"accordion\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_accordion/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_accordion/1","doc":"```heex\n<.accordion id=\"dog-breeds\">\n  <:section title=\"Golden Retriever\">\n     \n      Friendly, intelligent, great with families. Origin: Scotland. Needs\n      regular exercise.\n     \n  </:section>\n  <:section title=\"Siberian Husky\">\n     \n      Energetic, outgoing, distinctive appearance. Origin: Northeast Asia.\n      Loves cold climates.\n     \n  </:section>\n  <:section title=\"Dachshund\">\n     \n      Playful, stubborn, small size. Origin: Germany. Enjoys sniffing games.\n     \n  </:section>\n</.accordion>\n```","ref":"Doggo.Components.html#build_accordion/1-usage"},{"type":"macro","title":"Doggo.Components.build_action_bar/1","doc":"The action bar offers users quick access to primary actions within the\napplication.\n\nIt is typically positioned to float above other content.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Roving tabindex\n> - Move focus with arrow keys\n>","ref":"Doggo.Components.html#build_action_bar/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_action_bar/1","doc":"Generate component with default options:\n\n    build_action_bar()","ref":"Doggo.Components.html#build_action_bar/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_action_bar/1","doc":"```elixir\n[\n  name: :action_bar,\n  base_class: \"action-bar\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_action_bar/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_action_bar/1","doc":"```heex\n<.action_bar>\n  <:item label=\"Edit\" on_click={JS.push(\"edit\")}>\n    <.icon> </.icon>\n  </:item>\n  <:item label=\"Move\" on_click={JS.push(\"move\")}>\n    <.icon> </.icon>\n  </:item>\n  <:item label=\"Archive\" on_click={JS.push(\"archive\")}>\n    <.icon> </.icon>\n  </:item>\n</.action_bar>\n```","ref":"Doggo.Components.html#build_action_bar/1-usage"},{"type":"macro","title":"Doggo.Components.build_alert/1","doc":"The alert component serves as a notification mechanism to provide feedback to\nthe user.\n\nFor supplementary information that doesn't require the user's immediate\nattention, use `callout/1` instead.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_alert/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_alert/1","doc":"Generate component with default options:\n\n    build_alert()","ref":"Doggo.Components.html#build_alert/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_alert/1","doc":"```elixir\n[\n  name: :alert,\n  base_class: \"alert\",\n  modifiers: [\n    level: [values: [\"info\", \"success\", \"warning\", \"danger\"], default: \"info\"]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_alert/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_alert/1","doc":"Minimal example:\n\n```heex\n<.alert id=\"some-alert\"></.alert>\n```\n\nWith title, icon and level:\n\n```heex\n<.alert id=\"some-alert\" level={:info} title=\"Info\">\n  message\n  <:icon> </:icon>\n</.alert>\n```","ref":"Doggo.Components.html#build_alert/1-usage"},{"type":"macro","title":"Doggo.Components.build_alert_dialog/1","doc":"Renders an alert dialog that requires the immediate attention and response of\nthe user.\n\nThis component is meant for situations where critical information must be\nconveyed, and an explicit response is required from the user. It is typically\nused for confirmation dialogs, warning messages, error notifications, and\nother scenarios where an immediate decision is necessary.\n\nFor non-critical dialogs, such as those containing forms or additional\ninformation, use `Doggo.Components.build_modal/1` instead.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_alert_dialog/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_alert_dialog/1","doc":"Generate component with default options:\n\n    build_alert_dialog()","ref":"Doggo.Components.html#build_alert_dialog/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_alert_dialog/1","doc":"```elixir\n[\n  name: :alert_dialog,\n  base_class: \"alert-dialog\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_alert_dialog/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_alert_dialog/1","doc":"```heex\n<.alert_dialog id=\"end-session-modal\">\n  <:title>End Training Session Early?</:title>\n   \n    Are you sure you want to end the current training session with Bella?\n    She's making great progress today!\n   \n  <:footer>\n    <.button phx-click=\"end-session\">\n      Yes, end session\n    </.button>\n    <.button phx-click={JS.exec(\"data-cancel\", to: \"#end-session-modal\")}>\n      No, continue training\n    </.button>\n  </:footer>\n</.alert_dialog>\n```\n\nTo open the dialog, use the `show_modal/1` function.\n\n```heex\n<.button\n  phx-click={.show_modal(\"end-session-modal\")}\n  aria-haspopup=\"dialog\"\n>\n  show\n</.button>\n```","ref":"Doggo.Components.html#build_alert_dialog/1-usage"},{"type":"macro","title":"CSS - Doggo.Components.build_alert_dialog/1","doc":"To hide the modal when the `open` attribute is not set, use the following CSS\nstyles:\n\n```css\ndialog.alert-dialog:not([open]),\ndialog.alert-dialog[open=\"false\"] {\n  display: none;\n}\n```","ref":"Doggo.Components.html#build_alert_dialog/1-css"},{"type":"macro","title":"Semantics - Doggo.Components.build_alert_dialog/1","doc":"While the `showModal()` JavaScript function is typically recommended for\nmanaging modal dialog semantics, this component utilizes the `open` attribute\nto control visibility. This approach is chosen to eliminate the need for\nlibrary consumers to add additional JavaScript code. To ensure proper\nmodal semantics, the `aria-modal` attribute is added to the dialog element.","ref":"Doggo.Components.html#build_alert_dialog/1-semantics"},{"type":"macro","title":"Doggo.Components.build_app_bar/1","doc":"The app bar is typically located at the top of the interface and provides\naccess to key features and navigation options.\n\n\n> #### Maturity: Experimental {: .info}","ref":"Doggo.Components.html#build_app_bar/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_app_bar/1","doc":"Generate component with default options:\n\n    build_app_bar()","ref":"Doggo.Components.html#build_app_bar/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_app_bar/1","doc":"```elixir\n[\n  name: :app_bar,\n  base_class: \"app-bar\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_app_bar/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_app_bar/1","doc":"```heex\n<.app_bar title=\"Page title\">\n  <:navigation label=\"Open menu\" on_click={JS.push(\"toggle-menu\")}>\n    <.icon> </.icon>\n  </:navigation>\n  <:action label=\"Search\" on_click={JS.push(\"search\")}>\n    <.icon> </.icon>\n  </:action>\n  <:action label=\"Like\" on_click={JS.push(\"like\")}>\n    <.icon> </.icon>\n  </:action>\n</.app_bar>\n```","ref":"Doggo.Components.html#build_app_bar/1-usage"},{"type":"macro","title":"Doggo.Components.build_avatar/1","doc":"Renders profile picture, typically to represent a user.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_avatar/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_avatar/1","doc":"Generate component with default options:\n\n    build_avatar()","ref":"Doggo.Components.html#build_avatar/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_avatar/1","doc":"```elixir\n[\n  name: :avatar,\n  base_class: \"avatar\",\n  modifiers: [\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"],\n    shape: [values: [nil, \"circle\"], default: nil]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_avatar/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_avatar/1","doc":"Minimal example with only the `src` attribute:\n\n```heex\n<.avatar src=\"avatar.png\" />\n```\n\nRender avatar as a circle:\n\n```heex\n<.avatar src=\"avatar.png\" circle />\n```\n\nUse a placeholder image in case the avatar is not set:\n\n```heex\n<.avatar src={@user.avatar_url} placeholder_src=\"fallback.png\" />\n```\n\nRender an text as the placeholder value:\n\n```heex\n<.avatar src={@user.avatar_url} placeholder_content=\"A\" />\n```","ref":"Doggo.Components.html#build_avatar/1-usage"},{"type":"macro","title":"Doggo.Components.build_badge/1","doc":"Generates a badge component, typically used for drawing attention to elements\nlike notification counts.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_badge/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_badge/1","doc":"Generate component with default options:\n\n    build_badge()","ref":"Doggo.Components.html#build_badge/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_badge/1","doc":"```elixir\n[\n  name: :badge,\n  base_class: \"badge\",\n  modifiers: [\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"],\n    variant: [\n      values: [nil, \"primary\", \"secondary\", \"info\", \"success\", \"warning\",\n       \"danger\"],\n      default: nil\n    ]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_badge/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_badge/1","doc":"```heex\n<.badge>8</.badge>\n```","ref":"Doggo.Components.html#build_badge/1-usage"},{"type":"macro","title":"Doggo.Components.build_bottom_navigation/1","doc":"Renders a navigation that sticks to the bottom of the screen.\n\n\n> #### Maturity: Experimental {: .info}","ref":"Doggo.Components.html#build_bottom_navigation/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_bottom_navigation/1","doc":"Generate component with default options:\n\n    build_bottom_navigation()","ref":"Doggo.Components.html#build_bottom_navigation/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_bottom_navigation/1","doc":"```elixir\n[\n  name: :bottom_navigation,\n  base_class: \"bottom-navigation\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_bottom_navigation/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_bottom_navigation/1","doc":"```heex\n<.bottom_navigation current_value={@view}>\n  <:item\n    label=\"Profile\"\n    navigate={~p\"/pets/#{@pet}\"}\n    value={Profile}\n  >\n     \n  </:item>\n  <:item\n    label=\"Appointments\"\n    navigate={~p\"/pets/#{@pet}/appointments\"}\n    value={Appointments}\n  >\n     \n  </:item>\n  <:item\n    label=\"Messages\"\n    navigate={~p\"/pets/#{@pet}/messages\"}\n    value={Messages}\n  >\n     \n  </:item>\n</.bottom_navigation>\n```","ref":"Doggo.Components.html#build_bottom_navigation/1-usage"},{"type":"macro","title":"Doggo.Components.build_box/1","doc":"Renders a box for a section on the page.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_box/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_box/1","doc":"Generate component with default options:\n\n    build_box()","ref":"Doggo.Components.html#build_box/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_box/1","doc":"```elixir\n[\n  name: :box,\n  base_class: \"box\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_box/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_box/1","doc":"Minimal example with only a box body:\n\n```heex\n<.box>\n   This is a box. \n</.box>\n```\n\nWith title, banner, action, and footer:\n\n```heex\n \n  <:title>Profile</:title>\n  <:banner>\n     \n  </:banner>\n  <:action>\n     Edit \n  </:action>\n\n   This is a profile. \n\n  <:footer>\n     Last edited: <%= @profile.updated_at %> \n  </:footer>\n \n```","ref":"Doggo.Components.html#build_box/1-usage"},{"type":"macro","title":"Doggo.Components.build_breadcrumb/1","doc":"Renders a breadcrumb navigation.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_breadcrumb/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_breadcrumb/1","doc":"Generate component with default options:\n\n    build_breadcrumb()","ref":"Doggo.Components.html#build_breadcrumb/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_breadcrumb/1","doc":"```elixir\n[\n  name: :breadcrumb,\n  base_class: \"breadcrumb\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_breadcrumb/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_breadcrumb/1","doc":"```heex\n<.breadcrumb>\n  <:item patch=\"/categories\">Categories</:item>\n  <:item patch=\"/categories/1\">Reviews</:item>\n  <:item patch=\"/categories/1/articles/1\">The Movie</:item>\n</.breadcrumb>\n```","ref":"Doggo.Components.html#build_breadcrumb/1-usage"},{"type":"macro","title":"Doggo.Components.build_button/1","doc":"Renders a button.\n\nUse this component when you need to perform an action that doesn't involve\nnavigating to a different page, such as submitting a form, confirming an\naction, or deleting an item.\n\nIf you need to navigate to a different page or a specific section on the\ncurrent page and want to style the link like a button, use `button_link/1`\ninstead.\n\nSee also `button_link/1`, `toggle_button/1`, and `disclosure_button/1`.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_button/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_button/1","doc":"Generate component with default options:\n\n    build_button()","ref":"Doggo.Components.html#build_button/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_button/1","doc":"```elixir\n[\n  name: :button,\n  base_class: \"button\",\n  modifiers: [\n    variant: [\n      values: [\"primary\", \"secondary\", \"info\", \"success\", \"warning\", \"danger\"],\n      default: \"primary\"\n    ],\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"],\n    fill: [values: [\"solid\", \"outline\", \"text\"], default: \"solid\"],\n    shape: [values: [nil, \"circle\", \"pill\"], default: nil]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_button/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_button/1","doc":"```heex\n<.button>Confirm</.button>\n\n<.button type=\"submit\">\n  Submit\n</.button>\n```\n\nTo indicate a loading state, for example when submitting a form, use the\n`aria-busy` attribute:\n\n```heex\n<.button aria-label=\"Saving...\" aria-busy>\n  click me\n</.button>\n```","ref":"Doggo.Components.html#build_button/1-usage"},{"type":"macro","title":"Doggo.Components.build_button_link/1","doc":"Renders a link (` `) that has the role and style of a button.\n\nUse this component when you need to style a link to a different page or a\nspecific section within the same page as a button.\n\nTo perform an action on the same page, including toggles and revealing/hiding\nelements, you should always use a real button instead. See `button/1`,\n`toggle_button/1`, and `disclosure_button/1`.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_button_link/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_button_link/1","doc":"Generate component with default options:\n\n    build_button_link()","ref":"Doggo.Components.html#build_button_link/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_button_link/1","doc":"```elixir\n[\n  name: :button_link,\n  base_class: \"button\",\n  modifiers: [\n    variant: [\n      values: [\"primary\", \"secondary\", \"info\", \"success\", \"warning\", \"danger\"],\n      default: \"primary\"\n    ],\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"],\n    fill: [values: [\"solid\", \"outline\", \"text\"], default: \"solid\"],\n    shape: [values: [nil, \"circle\", \"pill\"], default: nil]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2,\n  disabled_class: \"is-disabled\"\n]\n```","ref":"Doggo.Components.html#build_button_link/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_button_link/1","doc":"```heex\n<.button_link patch={~p\"/confirm\"}>\n  Confirm\n</.button_link>\n\n<.button_link navigate={~p\"/registration\"}>\n  Registration\n</.button_link>\n```","ref":"Doggo.Components.html#build_button_link/1-usage"},{"type":"macro","title":"Doggo.Components.build_callout/1","doc":"Use the callout to highlight supplementary information related to the main\ncontent.\n\nFor information that needs immediate attention of the user, use `alert/1`\ninstead.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_callout/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_callout/1","doc":"Generate component with default options:\n\n    build_callout()","ref":"Doggo.Components.html#build_callout/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_callout/1","doc":"```elixir\n[\n  name: :callout,\n  base_class: \"callout\",\n  modifiers: [\n    variant: [values: [\"info\", \"success\", \"warning\", \"danger\"], default: \"info\"]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_callout/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_callout/1","doc":"Standard callout:\n\n```heex\n<.callout title=\"Dog Care Tip\">\n   Regular exercise is essential for keeping your dog healthy and happy. \n</.callout>\n```\n\nCallout with an icon:\n\n```heex\n<.callout title=\"Fun Dog Fact\">\n  <:icon> </:icon>\n   \n    Did you know? Dogs have a sense of time and can get upset when their\n    routine is changed.\n   \n</.callout>\n```","ref":"Doggo.Components.html#build_callout/1-usage"},{"type":"macro","title":"Doggo.Components.build_card/1","doc":"Renders a card in an `article` tag, typically used repetitively in a grid or\nflex box layout.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_card/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_card/1","doc":"Generate component with default options:\n\n    build_card()","ref":"Doggo.Components.html#build_card/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_card/1","doc":"```elixir\n[\n  name: :card,\n  base_class: \"card\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_card/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_card/1","doc":"```heex\n<.card>\n  <:image>\n     \n  </:image>\n  <:header> Dog Fashion Show </:header>\n  <:main>\n    The next dog fashion show is coming up quickly. Here's what you need\n    to look out for.\n  </:main>\n  <:footer>\n     2023-11-15 12:24 \n     Events \n  </:footer>\n</.card>\n```","ref":"Doggo.Components.html#build_card/1-usage"},{"type":"macro","title":"Doggo.Components.build_carousel/1","doc":"Renders a carousel for presenting a sequence of items, such as images or text.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Handle previous/next buttons\n> - Handle pagination tabs\n> - Auto rotation\n> - Disable auto rotation when controls are used\n> - Disable previous/next button on first/last item.\n> - Focus management and keyboard support for pagination\n>","ref":"Doggo.Components.html#build_carousel/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_carousel/1","doc":"Generate component with default options:\n\n    build_carousel()","ref":"Doggo.Components.html#build_carousel/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_carousel/1","doc":"```elixir\n[\n  name: :carousel,\n  base_class: \"carousel\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_carousel/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_carousel/1","doc":"```heex\n<.carousel label=\"Our Dogs\">\n  <:previous label=\"Previous Slide\">\n     \n  </:previous>\n  <:next label=\"Next Slide\">\n     \n  </:next>\n  <:item label=\"1 of 3\">\n    <.image\n      src=\"https://github.com/woylie/doggo/blob/main/assets/dog_poncho.jpg?raw=true\"\n      alt=\"A dog wearing a colorful poncho walks down a fashion show runway.\"\n      ratio={{16, 9}}\n    />\n  </:item>\n  <:item label=\"2 of 3\">\n    <.image\n      src=\"https://github.com/woylie/doggo/blob/main/assets/dog_poncho.jpg?raw=true\"\n      alt=\"A dog dressed in a sumptuous, baroque-style costume, complete with jewels and intricate embroidery, parades on an ornate runway at a luxurious fashion show, embodying opulence and grandeur.\"\n      ratio={{16, 9}}\n    />\n  </:item>\n  <:item label=\"3 of 3\">\n    <.image\n      src=\"https://github.com/woylie/doggo/blob/main/assets/dog_poncho.jpg?raw=true\"\n      alt=\"A dog adorned in a lavish, flamboyant outfit, including a large feathered hat and elaborate jewelry, struts confidently down a luxurious fashion show runway, surrounded by bright lights and an enthusiastic audience.\"\n      ratio={{16, 9}}\n    />\n  </:item>\n</.carousel>\n```","ref":"Doggo.Components.html#build_carousel/1-usage"},{"type":"macro","title":"Doggo.Components.build_cluster/1","doc":"Use the cluster component to visually group children.\n\nCommon use cases are groups of buttons, or group of tags.\n\n\n> #### Maturity: Refining {: .info}","ref":"Doggo.Components.html#build_cluster/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_cluster/1","doc":"Generate component with default options:\n\n    build_cluster()","ref":"Doggo.Components.html#build_cluster/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_cluster/1","doc":"```elixir\n[\n  name: :cluster,\n  base_class: \"cluster\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_cluster/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_cluster/1","doc":"```heex\n<.cluster>\n   some item \n   some other item \n</.cluster>\n```","ref":"Doggo.Components.html#build_cluster/1-usage"},{"type":"macro","title":"Doggo.Components.build_combobox/1","doc":"Renders a text input with a popup that allows users to select a value from\na list of suggestions.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Showing/hiding suggestions\n> - Filtering suggestions\n> - Selecting a value\n> - Focus management\n> - Keyboard support\n>","ref":"Doggo.Components.html#build_combobox/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_combobox/1","doc":"Generate component with default options:\n\n    build_combobox()","ref":"Doggo.Components.html#build_combobox/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_combobox/1","doc":"```elixir\n[\n  name: :combobox,\n  base_class: \"combobox\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_combobox/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_combobox/1","doc":"With simple values:\n\n```heex\n<.combobox\n  id=\"dog-breed-selector\"\n  name=\"breed\"\n  list_label=\"Dog breeds\"\n  options={[\n    \"Labrador Retriever\",\n    \"German Shepherd\",\n    \"Golden Retriever\",\n    \"French Bulldog\",\n    \"Bulldog\"\n  ]}\n/>\n```\n\nWith label/value pairs:\n\n```heex\n<.combobox\n  id=\"dog-breed-selector\"\n  name=\"breed\"\n  list_label=\"Dog breeds\"\n  options={[\n    {\"Labrador Retriever\", \"labrador\"},\n    {\"German Shepherd\", \"german_shepherd\"},\n    {\"Golden Retriever\", \"golden_retriever\"},\n    {\"French Bulldog\", \"french_bulldog\"},\n    {\"Bulldog\", \"bulldog\"}\n  ]}\n/>\n```\n\nWith label/value/description tuples:\n\n```heex\n<.combobox\n  id=\"dog-breed-selector\"\n  name=\"breed\"\n  list_label=\"Dog breeds\"\n  options={[\n    {\"Labrador Retriever\", \"labrador\", \"Friendly and outgoing\"},\n    {\"German Shepherd\", \"german_shepherd\", \"Confident and smart\"},\n    {\"Golden Retriever\", \"golden_retriever\", \"Intelligent and friendly\"},\n    {\"French Bulldog\", \"french_bulldog\", \"Adaptable and playful\"},\n    {\"Bulldog\", \"bulldog\", \"Docile and willful\"}\n  ]}\n/>\n```","ref":"Doggo.Components.html#build_combobox/1-usage"},{"type":"macro","title":"Doggo.Components.build_date/1","doc":"Renders a `Date`, `DateTime`, or `NaiveDateTime` in a ` ` tag.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_date/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_date/1","doc":"Generate component with default options:\n\n    build_date()","ref":"Doggo.Components.html#build_date/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_date/1","doc":"```elixir\n[\n  name: :date,\n  base_class: nil,\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_date/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_date/1","doc":"By default, the given value is formatted for display with `to_string/1`. This:\n\n```heex\n<.date value={~D[2023-02-05]} />\n```\n\nWill be rendered as:\n\n```html\n \n  2023-02-05\n \n```\n\nYou can also pass a custom formatter function. For example, if you are using\n[ex_cldr_dates_times](https://hex.pm/packages/ex_cldr_dates_times) in your\napplication, you could do this:\n\n```heex\n<.date\n  value={~D[2023-02-05]}\n  formatter={&MyApp.Cldr.Date.to_string!/1}\n/>\n```\n\nWhich, depending on your locale, may be rendered as:\n\n```html\n \n  Feb 2, 2023\n \n```","ref":"Doggo.Components.html#build_date/1-usage"},{"type":"macro","title":"Doggo.Components.build_datetime/1","doc":"Renders a `DateTime` or `NaiveDateTime` in a ` ` tag.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_datetime/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_datetime/1","doc":"Generate component with default options:\n\n    build_datetime()","ref":"Doggo.Components.html#build_datetime/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_datetime/1","doc":"```elixir\n[\n  name: :datetime,\n  base_class: nil,\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_datetime/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_datetime/1","doc":"By default, the given value is formatted for display with `to_string/1`. This:\n\n```heex\n<.datetime value={~U[2023-02-05 12:22:06.003Z]} />\n```\n\nWill be rendered as:\n\n```html\n \n  2023-02-05 12:22:06.003Z\n \n```\n\nYou can also pass a custom formatter function. For example, if you are using\n[ex_cldr_dates_times](https://hex.pm/packages/ex_cldr_dates_times) in your\napplication, you could do this:\n\n```heex\n<.datetime\n  value={~U[2023-02-05 14:22:06.003Z]}\n  formatter={&MyApp.Cldr.DateTime.to_string!/1}\n/>\n```\n\nWhich, depending on your locale, may be rendered as:\n\n```html\n \n  Feb 2, 2023, 14:22:06 PM\n \n```","ref":"Doggo.Components.html#build_datetime/1-usage"},{"type":"macro","title":"Doggo.Components.build_disclosure_button/1","doc":"Renders a button that toggles the visibility of another element.\n\nUse this component to reveal or hide additional content, such as in\ncollapsible sections or dropdown menus.\n\nFor a button that toggles other states, use `toggle_button/1` instead. See\nalso `button/1` and `button_link/1`.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_disclosure_button/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_disclosure_button/1","doc":"Generate component with default options:\n\n    build_disclosure_button()","ref":"Doggo.Components.html#build_disclosure_button/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_disclosure_button/1","doc":"```elixir\n[\n  name: :disclosure_button,\n  base_class: \"button\",\n  modifiers: [\n    variant: [\n      values: [\"primary\", \"secondary\", \"info\", \"success\", \"warning\", \"danger\"],\n      default: \"primary\"\n    ],\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"],\n    fill: [values: [\"solid\", \"outline\", \"text\"], default: \"solid\"],\n    shape: [values: [nil, \"circle\", \"pill\"], default: nil]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_disclosure_button/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_disclosure_button/1","doc":"Set the `controls` attribute to the DOM ID of the element that you want to\ntoggle with the button.\n\nThe initial state is hidden. Do not forget to add the `hidden` attribute to\nthe toggled element. Otherwise, visibility of the element will not align with\nthe `aria-expanded` attribute of the button.\n\n```heex\n<.disclosure_button controls=\"data-table\">\n  Data Table\n</.disclosure_button>\n\n  \n```","ref":"Doggo.Components.html#build_disclosure_button/1-usage"},{"type":"macro","title":"Doggo.Components.build_drawer/1","doc":"Renders a drawer with a `brand`, `top`, and `bottom` slot.\n\nAll slots are optional, and you can render any content in them. If you want\nto use the drawer as a sidebar, you can use the `vertical_nav/1` and\n`vertical_nav_section/1` components.\n\n\n> #### Maturity: Experimental {: .info}","ref":"Doggo.Components.html#build_drawer/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_drawer/1","doc":"Generate component with default options:\n\n    build_drawer()","ref":"Doggo.Components.html#build_drawer/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_drawer/1","doc":"```elixir\n[\n  name: :drawer,\n  base_class: \"drawer\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_drawer/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_drawer/1","doc":"Minimal example:\n\n```heex\n<.drawer>\n  <:main>Content</:main>\n</.drawer>\n```\n\nWith all slots:\n\n```heex\n<.drawer>\n  <:header>Doggo</:header>\n  <:main>Content at the top</:main>\n  <:footer>Content at the bottom</:footer>\n</.drawer>\n```\n\nWith navigation and sections:\n\n```heex\n<.drawer>\n  <:header>\n    <.link navigate={~p\"/\"}>App</.link>\n  </:header>\n  <:main>\n    <.vertical_nav label=\"Main\">\n      <:item>\n        <.link navigate={~p\"/dashboard\"}>Dashboard</.link>\n      </:item>\n      <:item>\n        <.vertical_nav_nested>\n          <:title>Content</:title>\n          <:item current_page>\n            <.link navigate={~p\"/posts\"}>Posts</.link>\n          </:item>\n          <:item>\n            <.link navigate={~p\"/comments\"}>Comments</.link>\n          </:item>\n        </.vertical_nav_nested>\n      </:item>\n    </.vertical_nav>\n    <.vertical_nav_section>\n      <:title>Search</:title>\n      <:item> </:item>\n    </.vertical_nav_section>\n  </:main>\n  <:footer>\n    <.vertical_nav label=\"User menu\">\n      <:item>\n        <.link navigate={~p\"/settings\"}>Settings</.link>\n      </:item>\n      <:item>\n        <.link navigate={~p\"/logout\"}>Logout</.link>\n      </:item>\n    </.vertical_nav>\n  </:footer>\n</.drawer>\n```","ref":"Doggo.Components.html#build_drawer/1-usage"},{"type":"macro","title":"Doggo.Components.build_fab/1","doc":"Renders a floating action button.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_fab/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_fab/1","doc":"Generate component with default options:\n\n    build_fab()","ref":"Doggo.Components.html#build_fab/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_fab/1","doc":"```elixir\n[\n  name: :fab,\n  base_class: \"fab\",\n  modifiers: [\n    variant: [\n      values: [\"primary\", \"secondary\", \"info\", \"success\", \"warning\", \"danger\"],\n      default: \"primary\"\n    ],\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"],\n    shape: [values: [nil, \"circle\", \"pill\"], default: \"circle\"]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_fab/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_fab/1","doc":"```heex\n<.fab label=\"Add item\" phx-click={JS.patch(to: \"/items/new\")}>\n  <.icon> </.icon>\n</.fab>\n```","ref":"Doggo.Components.html#build_fab/1-usage"},{"type":"macro","title":"Doggo.Components.build_fallback/1","doc":"The fallback component renders a given value unless it is empty, in which case\nit renders a fallback value instead.\n\nThe values `nil`, `\"\"`, `[]` and `%{}` are treated as empty values.\n\nThis component optionally applies a formatter function to non-empty values.\n\nThe primary purpose of this component is to enhance accessibility. In\nsituations where a value in a table column or property list is set to be\ninvisible or not displayed, it's crucial to provide an alternative text for\nscreen readers.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_fallback/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_fallback/1","doc":"Generate component with default options:\n\n    build_fallback()","ref":"Doggo.Components.html#build_fallback/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_fallback/1","doc":"```elixir\n[\n  name: :fallback,\n  base_class: \"fallback\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_fallback/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_fallback/1","doc":"Render the value of `@some_value` if it's available, or display the\ndefault placeholder otherwise:\n\n```heex\n<.fallback value={@some_value} />\n```\n\nApply a formatter function to `@some_value` if it is not `nil`:\n\n```heex\n<.fallback value={@some_value} formatter={&format_date/1} />\n```\n\nSet a custom placeholder and text for screen readers:\n\n```heex\n<.fallback\n  value={@some_value}\n  placeholder=\"n/a\"\n  accessibility_text=\"not available\"\n/>\n```","ref":"Doggo.Components.html#build_fallback/1-usage"},{"type":"macro","title":"Doggo.Components.build_field/1","doc":"Renders a form field including input, label, errors, and description.\n\nA `Phoenix.HTML.FormField` may be passed as argument,\nwhich is used to retrieve the input name, id, and values.\nOtherwise all attributes may be passed explicitly.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_field/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_field/1","doc":"Generate component with default options:\n\n    build_field()","ref":"Doggo.Components.html#build_field/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_field/1","doc":"```elixir\n[\n  name: :field,\n  base_class: \"field\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2,\n  gettext_module: nil,\n  addon_left_class: \"has-addon-left\",\n  addon_right_class: \"has-addon-right\"\n]\n```","ref":"Doggo.Components.html#build_field/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_field/1","doc":"","ref":"Doggo.Components.html#build_field/1-usage"},{"type":"macro","title":"Dependencies - Doggo.Components.build_field/1","doc":"This component requires the `field_description`, `field_errors`,\n`field_group`, and `label` components to be compiled with their default\nnames in the same module.","ref":"Doggo.Components.html#build_field/1-dependencies"},{"type":"macro","title":"Types - Doggo.Components.build_field/1","doc":"In addition to all HTML input types, the following type values are also\nsupported:\n\n- `\"select\"`\n- `\"checkbox-group\"`\n- `\"radio-group\"`\n- `\"switch\"`","ref":"Doggo.Components.html#build_field/1-types"},{"type":"macro","title":"Class and Global Attribute - Doggo.Components.build_field/1","doc":"Note that the `class` attribute is applied to the outer container, while\nthe `rest` global attribute is applied to the ` ` element.","ref":"Doggo.Components.html#build_field/1-class-and-global-attribute"},{"type":"macro","title":"Gettext - Doggo.Components.build_field/1","doc":"To translate field errors using Gettext, set the `gettext_module` option\nwhen building the component:\n\n    build_field(gettext_module: MyApp.Gettext)","ref":"Doggo.Components.html#build_field/1-gettext"},{"type":"macro","title":"Label positioning - Doggo.Components.build_field/1","doc":"The component does not provide an attribute to modify label positioning\ndirectly. Instead, label positioning should be handled with CSS. If your\napplication requires different label positions, such as horizontal and\nvertical layouts, it is recommended to add a modifier class to the form.\n\nFor example, the default style could position labels above inputs. To place\nlabels to the left of the inputs in a horizontal form layout, you can add an\n`is-horizontal` class to the form:\n\n```heex\n<.form class=\"is-horizontal\">\n  <!-- inputs -->\n</.form>\n```\n\nThen, in your CSS, apply the necessary styles to the `.field` class within\nforms having the `is-horizontal` class:\n\n```css\nform.is-horizontal .field {\n  // styles to position label left of the input\n}\n```\n\nThe component has a `hide_label` attribute to visually hide labels while still\nmaking them accessible to screen readers. If all labels within a form need to\nbe visually hidden, it may be more convenient to define a\n`.has-visually-hidden-labels` modifier class for the ` `.\n\n```heex\n<.form class=\"has-visually-hidden-labels\">\n  <!-- inputs -->\n</.form>\n```\n\nEnsure to take checkbox and radio labels into consideration when writing the\nCSS styles.","ref":"Doggo.Components.html#build_field/1-label-positioning"},{"type":"macro","title":"Examples - Doggo.Components.build_field/1","doc":"```heex\n<.field field={@form[:name]} />\n```\n\n```heex\n<.field field={@form[:email]} type=\"email\" />\n```\n\n#### Radio group and checkbox group\n\nThe `radio-group` and `checkbox-group` types allow you to easily render groups\nof radio buttons or checkboxes with a single component invocation. The\n`options` attribute is required for these types and has the same format as\nthe options for the `select` type, except that options may not be nested.\n\n```heex\n<.field\n  field={@form[:email]}\n  type=\"checkbox-group\"\n  label=\"Cuisine\"\n  options={[\n    {\"Mexican\", \"mexican\"},\n    {\"Japanese\", \"japanese\"},\n    {\"Libanese\", \"libanese\"}\n  ]}\n/>\n```\n\nNote that the `checkbox-group` type renders an additional hidden input with\nan empty value before the checkboxes. This ensures that a value exists in case\nall checkboxes are unchecked. Consequently, the resulting list value includes\nan extra empty string. While `Ecto.Changeset.cast/3` filters out empty strings\nin array fields by default, you may need to handle the additional empty string\nmanual in other contexts.","ref":"Doggo.Components.html#build_field/1-examples"},{"type":"macro","title":"Doggo.Components.build_field_description/1","doc":"Renders the description of an input.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_field_description/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_field_description/1","doc":"Generate component with default options:\n\n    build_field_description()","ref":"Doggo.Components.html#build_field_description/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_field_description/1","doc":"```elixir\n[\n  name: :field_description,\n  base_class: \"field-description\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_field_description/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_field_description/1","doc":"```heex\n<.field_description for=\"name\">\n  max. 100 characters\n</.field_description>\n```","ref":"Doggo.Components.html#build_field_description/1-usage"},{"type":"macro","title":"Doggo.Components.build_field_errors/1","doc":"Renders the errors for an input.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_field_errors/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_field_errors/1","doc":"Generate component with default options:\n\n    build_field_errors()","ref":"Doggo.Components.html#build_field_errors/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_field_errors/1","doc":"```elixir\n[\n  name: :field_errors,\n  base_class: \"field-errors\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_field_errors/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_field_errors/1","doc":"```heex\n<.field_errors for=\"name\" errors={[\"too many characters\"]} />\n```","ref":"Doggo.Components.html#build_field_errors/1-usage"},{"type":"macro","title":"Doggo.Components.build_field_group/1","doc":"Use the field group component to visually group multiple inputs in a form.\n\nThis component is intended for styling purposes and does not provide semantic\ngrouping. For semantic grouping of related form elements, use the ` `\nand ` ` HTML elements instead.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_field_group/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_field_group/1","doc":"Generate component with default options:\n\n    build_field_group()","ref":"Doggo.Components.html#build_field_group/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_field_group/1","doc":"```elixir\n[\n  name: :field_group,\n  base_class: \"field-group\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_field_group/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_field_group/1","doc":"Visual grouping of inputs:\n\n```heex\n<.field_group>\n  <.field field={@form[:given_name]} label=\"Given name\" />\n  <.field field={@form[:family_name]} label=\"Family name\"/>\n</.field_group>\n```\n\nSemantic grouping (for reference):\n\n```heex\n \n   Personal Information \n  <.field field={@form[:given_name]} label=\"Given name\" />\n  <.field field={@form[:family_name]} label=\"Family name\"/>\n \n```","ref":"Doggo.Components.html#build_field_group/1-usage"},{"type":"macro","title":"Doggo.Components.build_frame/1","doc":"Renders a frame with an aspect ratio for images or videos.\n\nThis component is used within the `image/1` component.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_frame/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_frame/1","doc":"Generate component with default options:\n\n    build_frame()","ref":"Doggo.Components.html#build_frame/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_frame/1","doc":"```elixir\n[\n  name: :frame,\n  base_class: \"frame\",\n  modifiers: [\n    ratio: [\n      values: [nil, \"1-by-1\", \"3-by-2\", \"2-by-3\", \"4-by-3\", \"3-by-4\", \"5-by-4\",\n       \"4-by-5\", \"16-by-9\", \"9-by-16\"],\n      default: nil\n    ],\n    shape: [values: [nil, \"circle\"], default: nil]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_frame/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_frame/1","doc":"Rendering an image with the aspect ratio 4:3.\n\n```heex\n<.frame ratio={{4, 3}}>\n   \n</.frame>\n```\n\nRendering an image as a circle.\n\n```heex\n<.frame circle>\n   \n</.frame>\n```","ref":"Doggo.Components.html#build_frame/1-usage"},{"type":"macro","title":"Doggo.Components.build_icon/1","doc":"Renders a customizable icon using a slot for SVG content.\n\nThis component does not bind you to a specific set of icons. Instead, it\nprovides a slot for inserting SVG content from any icon library you choose.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_icon/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_icon/1","doc":"Generate component with default options:\n\n    build_icon()","ref":"Doggo.Components.html#build_icon/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_icon/1","doc":"```elixir\n[\n  name: :icon,\n  base_class: \"icon\",\n  modifiers: [\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2,\n  visually_hidden_class: \"is-visually-hidden\"\n]\n```","ref":"Doggo.Components.html#build_icon/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_icon/1","doc":"Render an icon with text as `aria-label` using the `heroicons` library:\n\n```heex\n<.icon label=\"report bug\"> </.icon>\n```\n\nTo display the text visibly:\n\n```heex\n<.icon label=\"report bug\" label_placement={:right}>\n   \n</.icon>\n```\n\n> #### aria-hidden {: .info}\n>\n> Not all icon libraries set the `aria-hidden` attribute by default. Always\n> make sure that it is set on the ` ` element that the library renders.","ref":"Doggo.Components.html#build_icon/1-usage"},{"type":"macro","title":"Doggo.Components.build_icon_sprite/1","doc":"Renders an icon using an SVG sprite.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_icon_sprite/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_icon_sprite/1","doc":"Generate component with default options:\n\n    build_icon_sprite()","ref":"Doggo.Components.html#build_icon_sprite/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_icon_sprite/1","doc":"```elixir\n[\n  name: :icon_sprite,\n  base_class: \"icon\",\n  modifiers: [\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2,\n  visually_hidden_class: \"is-visually-hidden\"\n]\n```","ref":"Doggo.Components.html#build_icon_sprite/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_icon_sprite/1","doc":"Render an icon with text as `aria-label`:\n\n```heex\n<.icon name=\"arrow-left\" label=\"Go back\" />\n```\n\nTo display the text visibly:\n\n```heex\n<.icon name=\"arrow-left\" label=\"Go back\" label_placement={:right} />\n```","ref":"Doggo.Components.html#build_icon_sprite/1-usage"},{"type":"macro","title":"Doggo.Components.build_image/1","doc":"Renders an image with an optional caption.\n\nNote that this component relies on the frame component being compiled in the\nsame module with `frame/1` with the default name (`:frame`). If you\noverride the default ratios, ensure that both the `image` component and\nthe `frame` component are generated with the same values.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_image/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_image/1","doc":"Generate component with default options:\n\n    build_image()","ref":"Doggo.Components.html#build_image/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_image/1","doc":"```elixir\n[\n  name: :image,\n  base_class: \"image\",\n  modifiers: [\n    ratio: [\n      values: [nil, \"1-by-1\", \"3-by-2\", \"2-by-3\", \"4-by-3\", \"3-by-4\", \"5-by-4\",\n       \"4-by-5\", \"16-by-9\", \"9-by-16\"],\n      default: nil\n    ]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_image/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_image/1","doc":"```heex\n<.image\n  src=\"https://github.com/woylie/doggo/blob/main/assets/dog_poncho.jpg?raw=true\"\n  alt=\"A dog wearing a colorful poncho walks down a fashion show runway.\"\n  ratio={{16, 9}}\n>\n  <:caption>\n    Spotlight on canine couture: A dog fashion show where four-legged models\n    dazzle the runway with the latest in pet apparel.\n  </:caption>\n</.image>\n```","ref":"Doggo.Components.html#build_image/1-usage"},{"type":"macro","title":"Doggo.Components.build_label/1","doc":"Renders the label for an input.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_label/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_label/1","doc":"Generate component with default options:\n\n    build_label()","ref":"Doggo.Components.html#build_label/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_label/1","doc":"```elixir\n[\n  name: :label,\n  base_class: \"label\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2,\n  visually_hidden_class: \"is-visually-hidden\"\n]\n```","ref":"Doggo.Components.html#build_label/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_label/1","doc":"```heex\n<.label for=\"name\" required>\n  Name\n</.label>\n```","ref":"Doggo.Components.html#build_label/1-usage"},{"type":"macro","title":"Doggo.Components.build_menu/1","doc":"Renders a menu that offers a list of actions or functions.\n\nThis component is meant for organizing actions within an application, rather\nthan for navigating between different pages or sections of a website.\n\nSee also `menu_bar/1`, `menu_group/1`, `menu_button/1`, `menu_item/1`, and\n`menu_item_checkbox/1`.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Focus management\n> - keyboard support\n>","ref":"Doggo.Components.html#build_menu/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_menu/1","doc":"Generate component with default options:\n\n    build_menu()","ref":"Doggo.Components.html#build_menu/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_menu/1","doc":"```elixir\n[\n  name: :menu,\n  base_class: \"menu\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_menu/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_menu/1","doc":"If the menu is always visible or can only be toggled by a keyboard shortcut,\nset the `label` attribute.\n\n```heex\n<.menu label=\"Actions\">\n  <:item>Copy</:item>\n  <:item>Paste</:item>\n  <:item role=\"separator\"></:item>\n  <:item>Sort lines</:item>\n</.menu>\n```\n\nIf the menu is toggled by a `menu_button/1`, ensure that the `controls`\nattribute of the button matches the DOM ID of the menu and that the\n`labelledby` attribute of the menu matches the DOM ID of the button.\n\n<.menu_button controls=\"actions-menu\" id=\"actions-button\">\n  Actions\n</.menu_button>\n<.menu labelledby=\"actions-button\" hidden></.menu>","ref":"Doggo.Components.html#build_menu/1-usage"},{"type":"macro","title":"Doggo.Components.build_menu_bar/1","doc":"Renders a menu bar, similar to those found in desktop applications.\n\nThis component is meant for organizing actions within an application, rather\nthan for navigating between different pages or sections of a website.\n\nSee also `menu/1`, `menu_group/1`, `menu_button/1`, `menu_item/1`, and\n`menu_item_checkbox/1`.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Focus management\n> - keyboard support\n>","ref":"Doggo.Components.html#build_menu_bar/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_menu_bar/1","doc":"Generate component with default options:\n\n    build_menu_bar()","ref":"Doggo.Components.html#build_menu_bar/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_menu_bar/1","doc":"```elixir\n[\n  name: :menu_bar,\n  base_class: \"menu-bar\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_menu_bar/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_menu_bar/1","doc":"```heex\n<.menu_bar label=\"Main\">\n  <:item>\n    <.menu_button controls=\"actions-menu\" id=\"actions-button\">\n      Actions\n    </.menu_button>\n\n    <.menu id=\"actions-menu\" labelledby=\"actions-button\" hidden>\n      <:item>\n        <.menu_item on_click={JS.push(\"view-dog-profiles\")}>\n          View Dog Profiles\n        </.menu_item>\n      </:item>\n      <:item>\n        <.menu_item on_click={JS.push(\"add-dog-profile\")}>\n          Add Dog Profile\n        </.menu_item>\n      </:item>\n      <:item>\n        <.menu_item on_click={JS.push(\"dog-care-tips\")}>\n          Dog Care Tips\n        </.menu_item>\n      </:item>\n    </.menu>\n  </:item>\n  <:item role=\"separator\"></:item>\n  <:item>\n    <.menu_item on_click={JS.dispatch(\"myapp:help\")}>\n      Help\n    </.menu_item>\n  </:item>\n</.menu_bar>\n```","ref":"Doggo.Components.html#build_menu_bar/1-usage"},{"type":"macro","title":"Doggo.Components.build_menu_button/1","doc":"Renders a button that toggles an actions menu.\n\nThis component can be used on its own or as part of a `menu_bar/1` or `menu/1`.\nSee also `menu_item/1`, `menu_item_checkbox/1`, and `menu_group/1`.\n\nFor a button that toggles the visibility of an element that is not a menu, use\n`disclosure_button/1`. For a button that toggles other states, use\n`toggle_button/1`. See also `button/1` and `button_link/1`.\n\n\n> #### Maturity: Experimental {: .info}","ref":"Doggo.Components.html#build_menu_button/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_menu_button/1","doc":"Generate component with default options:\n\n    build_menu_button()","ref":"Doggo.Components.html#build_menu_button/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_menu_button/1","doc":"```elixir\n[\n  name: :menu_button,\n  base_class: \"menu-button\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_menu_button/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_menu_button/1","doc":"Set the `controls` attribute to the DOM ID of the element that you want to\ntoggle with the button.\n\nThe initial state is hidden. Do not forget to add the `hidden` attribute to\nthe toggled menu. Otherwise, visibility of the element will not align with\nthe `aria-expanded` attribute of the button.\n\n```heex\n \n  <.menu_button controls=\"actions-menu\" id=\"actions-button\">\n    Actions\n  </.menu_button>\n\n  <.menu id=\"actions-menu\" labelledby=\"actions-button\" hidden>\n    <:item>\n      <.menu_item on_click={JS.push(\"view-dog-profiles\")}>\n        View Dog Profiles\n      </.menu_item>\n    </:item>\n    <:item>\n      <.menu_item on_click={JS.push(\"add-dog-profile\")}>\n        Add Dog Profile\n      </.menu_item>\n    </:item>\n    <:item>\n      <.menu_item on_click={JS.push(\"dog-care-tips\")}>\n        Dog Care Tips\n      </.menu_item>\n    </:item>\n  </.menu>\n \n```\n\nIf this menu button is a child of a `menu_bar/1` or a `menu/1`, set the\n`menuitem` attribute.\n\n```heex\n<.menu id=\"actions-menu\">\n  <:item>\n    <.menu_button controls=\"actions-menu\" id=\"actions-button\" menuitem>\n      Dog Actions\n    </.menu_button>\n    <.menu id=\"dog-actions-menu\" labelledby=\"actions-button\" hidden>\n      <:item><!-- ... --></:item>\n    </.menu>\n  </:item>\n  <:item><!-- ... --></:item>\n</.menu>\n```","ref":"Doggo.Components.html#build_menu_button/1-usage"},{"type":"macro","title":"Doggo.Components.build_menu_group/1","doc":"This component can be used to group items within a `menu/1` or `menu_bar/1`.\n\nSee also `menu_button/1`, `menu_item/1`, and `menu_item_checkbox/1`.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Focus management\n> - Keyboard support\n>","ref":"Doggo.Components.html#build_menu_group/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_menu_group/1","doc":"Generate component with default options:\n\n    build_menu_group()","ref":"Doggo.Components.html#build_menu_group/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_menu_group/1","doc":"```elixir\n[\n  name: :menu_group,\n  base_class: \"menu-group\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_menu_group/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_menu_group/1","doc":"```heex\n<.menu id=\"actions-menu\" labelledby=\"actions-button\" hidden>\n  <:item>\n    <.menu_group label=\"Dog actions\">\n      <:item>\n        <.menu_item on_click={JS.push(\"view-dog-profiles\")}>\n          View Dog Profiles\n        </.menu_item>\n      </:item>\n      <:item>\n        <.menu_item on_click={JS.push(\"add-dog-profile\")}>\n          Add Dog Profile\n        </.menu_item>\n      </:item>\n      <:item>\n        <.menu_item on_click={JS.push(\"dog-care-tips\")}>\n          Dog Care Tips\n        </.menu_item>\n      </:item>\n    </.menu_group>\n  </:item>\n  <:item role=\"separator\" />\n  <:item>\n    <.menu_item on_click={JS.push(\"help\")}>Help</.menu_item>\n  </:item>\n</.menu>\n```","ref":"Doggo.Components.html#build_menu_group/1-usage"},{"type":"macro","title":"Doggo.Components.build_menu_item/1","doc":"Renders a button that acts as a menu item within a `menu/1` or `menu_bar/1`.\n\nA menu item is meant to be used to trigger an action. For a button that\ntoggles the visibility of a menu, use `menu_button/1`.\n\n\n> #### Maturity: Experimental {: .info}","ref":"Doggo.Components.html#build_menu_item/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_menu_item/1","doc":"Generate component with default options:\n\n    build_menu_item()","ref":"Doggo.Components.html#build_menu_item/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_menu_item/1","doc":"```elixir\n[\n  name: :menu_item,\n  base_class: \"menu-item\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_menu_item/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_menu_item/1","doc":"```heex\n<.menu label=\"Actions\">\n  <:item>\n    <.menu_item on_click={JS.dispatch(\"myapp:copy\")}>\n      Copy\n    </.menu_item>\n  </:item>\n  <:item>\n    <.menu_item on_click={JS.dispatch(\"myapp:paste\")}>\n      Paste\n    </.menu_item>\n  </:item>\n</.menu>\n```","ref":"Doggo.Components.html#build_menu_item/1-usage"},{"type":"macro","title":"Doggo.Components.build_menu_item_checkbox/1","doc":"Renders a menu item checkbox as part of a `menu/1` or `menu_bar/1`.\n\nSee also `menu_item/1`.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - State management\n> - Keyboard support\n>","ref":"Doggo.Components.html#build_menu_item_checkbox/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_menu_item_checkbox/1","doc":"Generate component with default options:\n\n    build_menu_item_checkbox()","ref":"Doggo.Components.html#build_menu_item_checkbox/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_menu_item_checkbox/1","doc":"```elixir\n[\n  name: :menu_item_checkbox,\n  base_class: \"menu-item-checkbox\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_menu_item_checkbox/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_menu_item_checkbox/1","doc":"```heex\n<.menu label=\"Actions\">\n  <:item>\n    <.menu_item_checkbox on_click={JS.dispatch(\"myapp:toggle-word-wrap\")}>\n      Word wrap\n    </.menu_item_checkbox>\n  </:item>\n</.menu>\n```","ref":"Doggo.Components.html#build_menu_item_checkbox/1-usage"},{"type":"macro","title":"Doggo.Components.build_menu_item_radio_group/1","doc":"Renders a group of menu item radios as part of a `menu/1` or `menu_bar/1`.\n\nSee also `menu_button/1`, `menu_item/1`, and `menu_item_checkbox/1`.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Focus management\n> - State management\n> - Keyboard support\n>","ref":"Doggo.Components.html#build_menu_item_radio_group/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_menu_item_radio_group/1","doc":"Generate component with default options:\n\n    build_menu_item_radio_group()","ref":"Doggo.Components.html#build_menu_item_radio_group/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_menu_item_radio_group/1","doc":"```elixir\n[\n  name: :menu_item_radio_group,\n  base_class: \"menu-item-radio-group\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_menu_item_radio_group/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_menu_item_radio_group/1","doc":"```heex\n<.menu id=\"actions-menu\" labelledby=\"actions-button\" hidden>\n  <:item>\n    <.menu_item_radio_group label=\"Theme\">\n      <:item on_click={JS.dispatch(\"switch-theme-light\")}>\n        Light\n      </:item>\n      <:item on_click={JS.dispatch(\"switch-theme-dark\")} checked>\n        Dark\n      </:item>\n    </.menu_item_radio_group>\n  </:item>\n</.menu>\n```","ref":"Doggo.Components.html#build_menu_item_radio_group/1-usage"},{"type":"macro","title":"Doggo.Components.build_modal/1","doc":"Renders a modal dialog for content such as forms and informational panels.\n\nThis component is appropriate for non-critical interactions. For dialogs\nrequiring immediate user response, such as confirmations or warnings, use\n`.alert_dialog/1` instead.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_modal/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_modal/1","doc":"Generate component with default options:\n\n    build_modal()","ref":"Doggo.Components.html#build_modal/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_modal/1","doc":"```elixir\n[\n  name: :modal,\n  base_class: \"modal\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_modal/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_modal/1","doc":"There are two primary ways to manage the display of the modal: via URL state\nor by setting and removing the `open` attribute.","ref":"Doggo.Components.html#build_modal/1-usage"},{"type":"macro","title":"With URL - Doggo.Components.build_modal/1","doc":"To toggle the modal visibility based on the URL:\n\n1. Use the `:if` attribute to conditionally render the modal when a specific\n   live action matches.\n2. Set the `on_cancel` attribute to patch back to the original URL when the\n   user chooses to close the modal.\n3. Set the `open` attribute to declare the modal's initial visibility state.\n\n#### Example\n\n```heex\n<.modal\n  :if={@live_action == :show}\n  id=\"pet-modal\"\n  on_cancel={JS.patch(~p\"/pets\")}\n  open\n>\n  <:title>Show pet</:title>\n   My pet is called Johnny. \n  <:footer>\n    <.link phx-click={JS.exec(\"data-cancel\", to: \"#pet-modal\")}>\n      Close\n    </.link>\n  </:footer>\n</.modal>\n```\n\nTo open the modal, patch or navigate to the URL associated with the live\naction.\n\n```heex\n<.link patch={~p\"/pets/#{@id}\"}>show</.link>\n```","ref":"Doggo.Components.html#build_modal/1-with-url"},{"type":"macro","title":"Without URL - Doggo.Components.build_modal/1","doc":"To toggle the modal visibility dynamically with the `open` attribute:\n\n1. Omit the `open` attribute in the template.\n2. Use the `show_modal/1` and `hide_modal/1` functions to change the\n   visibility.\n\n#### Example\n\n```heex\n<.modal id=\"pet-modal\">\n  <:title>Show pet</:title>\n   My pet is called Johnny. \n  <:footer>\n    <.link phx-click={JS.exec(\"data-cancel\", to: \"#pet-modal\")}>\n      Close\n    </.link>\n  </:footer>\n</.modal>\n```\n\nTo open modal, use the `show_modal/1` function.\n\n```heex\n<.button\n  phx-click={Doggo.show_modal(\"pet-modal\")}\n  aria-haspopup=\"dialog\"\n>\n  show\n</.button>\n```","ref":"Doggo.Components.html#build_modal/1-without-url"},{"type":"macro","title":"CSS - Doggo.Components.build_modal/1","doc":"To hide the modal when the `open` attribute is not set, use the following CSS\nstyles:\n\n```css\ndialog.modal:not([open]),\ndialog.modal[open=\"false\"] {\n  display: none;\n}\n```","ref":"Doggo.Components.html#build_modal/1-css"},{"type":"macro","title":"Semantics - Doggo.Components.build_modal/1","doc":"While the `showModal()` JavaScript function is typically recommended for\nmanaging modal dialog semantics, this component utilizes the `open` attribute\nto control visibility. This approach is chosen to eliminate the need for\nlibrary consumers to add additional JavaScript code. To ensure proper\nmodal semantics, the `aria-modal` attribute is added to the dialog element.","ref":"Doggo.Components.html#build_modal/1-semantics"},{"type":"macro","title":"Doggo.Components.build_navbar/1","doc":"Renders a navigation bar.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_navbar/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_navbar/1","doc":"Generate component with default options:\n\n    build_navbar()","ref":"Doggo.Components.html#build_navbar/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_navbar/1","doc":"```elixir\n[\n  name: :navbar,\n  base_class: \"navbar\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_navbar/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_navbar/1","doc":"```heex\n<.navbar>\n  <:brand><.link navigate={~p\"/\"}>Pet Clinic</.link></:brand>\n  <.navbar_items>\n    <:item><.link navigate={~p\"/about\"}>About</.link></:item>\n    <:item><.link navigate={~p\"/services\"}>Services</.link></:item>\n    <:item>\n      <.link navigate={~p\"/login\"} class=\"button\">Log in</.link>\n    </:item>\n  </.navbar_items>\n</.navbar>\n```\n\nYou can place multiple navigation item lists in the inner block. If the\n`.navbar` is styled as a flex box, you can use the CSS `order` property to\ncontrol the display order of the brand and lists.\n\n```heex\n<.navbar>\n  <:brand><.link navigate={~p\"/\"}>Pet Clinic</.link></:brand>\n  <.navbar_items class=\"navbar-main-links\">\n    <:item><.link navigate={~p\"/about\"}>About</.link></:item>\n    <:item><.link navigate={~p\"/services\"}>Services</.link></:item>\n  </.navbar_items>\n  <.navbar_items class=\"navbar-user-menu\">\n    <:item>\n      <.button_link navigate={~p\"/login\"}>Log in</.button_link>\n    </:item>\n  </.navbar_items>\n</.navbar>\n```\n\nIf you have multiple ` ` elements on your page, it is recommended to set\nthe `aria-label` attribute.\n\n```heex\n<.navbar aria-label=\"main navigation\">\n  <!-- ... -->\n</.navbar>\n```","ref":"Doggo.Components.html#build_navbar/1-usage"},{"type":"macro","title":"Doggo.Components.build_navbar_items/1","doc":"Renders a list of navigation items.\n\nMeant to be used in the inner block of the `navbar` component.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_navbar_items/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_navbar_items/1","doc":"Generate component with default options:\n\n    build_navbar_items()","ref":"Doggo.Components.html#build_navbar_items/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_navbar_items/1","doc":"```elixir\n[\n  name: :navbar_items,\n  base_class: \"navbar-items\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_navbar_items/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_navbar_items/1","doc":"```heex\n<.navbar_items>\n  <:item><.link navigate={~p\"/about\"}>About</.link></:item>\n  <:item><.link navigate={~p\"/services\"}>Services</.link></:item>\n  <:item>\n    <.link navigate={~p\"/login\"} class=\"button\">Log in</.link>\n  </:item>\n</.navbar_items>\n```","ref":"Doggo.Components.html#build_navbar_items/1-usage"},{"type":"macro","title":"Doggo.Components.build_page_header/1","doc":"Renders a header that is specific to the content of the current page.\n\nUnlike a site-wide header, which offers consistent navigation and elements\nlike logos throughout the website or application, this component is meant\nto describe the unique content of each page. For instance, on an article page,\nit would display the article's title.\n\nIt is typically used as a direct child of the ` ` element.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_page_header/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_page_header/1","doc":"Generate component with default options:\n\n    build_page_header()","ref":"Doggo.Components.html#build_page_header/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_page_header/1","doc":"```elixir\n[\n  name: :page_header,\n  base_class: \"page-header\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_page_header/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_page_header/1","doc":"```heex\n \n  <.page_header title=\"Puppy Profiles\" subtitle=\"Share Your Pup's Story\">\n    <:action>\n      <.button_link patch={~p\"/puppies/new\"}>Add New Profile</.button_link>\n    </:action>\n  </.page_header>\n\n   \n    <!-- Content -->\n   \n \n```","ref":"Doggo.Components.html#build_page_header/1-usage"},{"type":"macro","title":"Doggo.Components.build_property_list/1","doc":"Renders a list of properties, i.e. key/value pairs.\n\n\n> #### Maturity: Refining {: .info}","ref":"Doggo.Components.html#build_property_list/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_property_list/1","doc":"Generate component with default options:\n\n    build_property_list()","ref":"Doggo.Components.html#build_property_list/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_property_list/1","doc":"```elixir\n[\n  name: :property_list,\n  base_class: \"property-list\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_property_list/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_property_list/1","doc":"```heex\n<.property_list>\n  <:prop label={gettext(\"Name\")}>George</:prop>\n  <:prop label={gettext(\"Age\")}>42</:prop>\n</.property_list>\n```","ref":"Doggo.Components.html#build_property_list/1-usage"},{"type":"macro","title":"Doggo.Components.build_radio_group/1","doc":"Renders a group of radio buttons, for example for a toolbar.\n\nTo render radio buttons within a regular form, use `input/1` with the\n`\"radio-group\"` type instead.\n\n\n> #### Maturity: Experimental {: .info}","ref":"Doggo.Components.html#build_radio_group/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_radio_group/1","doc":"Generate component with default options:\n\n    build_radio_group()","ref":"Doggo.Components.html#build_radio_group/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_radio_group/1","doc":"```elixir\n[\n  name: :radio_group,\n  base_class: \"radio-group\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_radio_group/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_radio_group/1","doc":"```heex\n<.radio_group\n  id=\"favorite-dog\"\n  name=\"favorite-dog\"\n  label=\"Favorite Dog\"\n  options={[\n    {\"Labrador Retriever\", \"labrador\"},\n    {\"German Shepherd\", \"german_shepherd\"},\n    {\"Golden Retriever\", \"golden_retriever\"},\n    {\"French Bulldog\", \"french_bulldog\"},\n    {\"Beagle\", \"beagle\"}\n  ]}\n/>\n```","ref":"Doggo.Components.html#build_radio_group/1-usage"},{"type":"macro","title":"CSS - Doggo.Components.build_radio_group/1","doc":"To target the wrapper, you can use an attribute selector:\n\n```css\n[role=\"radio-group\"] {}\n```","ref":"Doggo.Components.html#build_radio_group/1-css"},{"type":"macro","title":"Doggo.Components.build_skeleton/1","doc":"Renders a skeleton loader, a placeholder for content that is in the process of\nloading.\n\nIt mimics the layout of the actual content, providing a better user experience\nduring loading phases.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_skeleton/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_skeleton/1","doc":"Generate component with default options:\n\n    build_skeleton()","ref":"Doggo.Components.html#build_skeleton/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_skeleton/1","doc":"```elixir\n[\n  name: :skeleton,\n  base_class: \"skeleton\",\n  modifiers: [\n    type: [\n      values: [\"text-line\", \"text-block\", \"image\", \"circle\", \"rectangle\",\n       \"square\"],\n      required: true\n    ]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_skeleton/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_skeleton/1","doc":"Render one of the primitive types in isolation:\n\n```heex\n<.skeleton type=\"text_line\" />\n```\n\nCombine primitives for complex layouts:\n\n```heex\n \n  <.skeleton type=\"image\" />\n  <.skeleton type=\"text-line\" />\n  <.skeleton type=\"text-line\" />\n  <.skeleton type=\"text-line\" />\n  <.skeleton type=\"rectangle\" />\n \n```\n\nTo modify the primitives for your use cases, you can either configure additional\nmodifiers or use CSS properties:\n\n```heex\n \n```\n\n```heex\n \n```","ref":"Doggo.Components.html#build_skeleton/1-usage"},{"type":"macro","title":"Aria-busy attribute - Doggo.Components.build_skeleton/1","doc":"When using skeleton loaders, apply `aria-busy=\"true\"` to the container element\nthat contains the skeleton layout. For standalone use, add the attribute\ndirectly to the individual skeleton loader.","ref":"Doggo.Components.html#build_skeleton/1-aria-busy-attribute"},{"type":"macro","title":"Async result component - Doggo.Components.build_skeleton/1","doc":"The easiest way to load data asynchronously and render a skeleton loader is\nto use LiveView's\n[async operations](`m:Phoenix.LiveView#module-async-operations`)\nand `Phoenix.Component.async_result/1`.\n\nAssuming you defined a card skeleton component as described above:\n\n```heex\n<.async_result :let={puppy} assign={@puppy}>\n  <:loading><.card_skeleton /></:loading>\n  <:failed :let={_reason}>There was an error loading the puppy.</:failed>\n  <!-- Card for loaded content -->\n</.async_result>\n```","ref":"Doggo.Components.html#build_skeleton/1-async-result-component"},{"type":"macro","title":"Doggo.Components.build_split_pane/1","doc":"Renders a horizontal or vertical resizable split pane.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Resize panes with the mouse\n> - Resize panes with the keyboard\n>","ref":"Doggo.Components.html#build_split_pane/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_split_pane/1","doc":"Generate component with default options:\n\n    build_split_pane()","ref":"Doggo.Components.html#build_split_pane/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_split_pane/1","doc":"```elixir\n[\n  name: :split_pane,\n  base_class: \"split-pane\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_split_pane/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_split_pane/1","doc":"Horizontal separator with label:\n\n```heex\n<.split_pane\n  id=\"sidebar-splitter\"\n  label=\"Sidebar\"\n  orientation=\"horizontal\"\n>\n  <:primary>One</:primary>\n  <:secondary>Two</:secondary>\n</.split_pane>\n```\n\nHorizontal separator with visible label:\n\n```heex\n<.split_pane id=\"sidebar-splitter\"\n  labelledby=\"sidebar-label\"\n  orientation=\"horizontal\"\n>\n  <:primary>\n     Sidebar \n     One \n  </:primary>\n  <:secondary>Two</:secondary>\n</.split_pane>\n```\n\nNested window splitters:\n\n```heex\n<.split_pane\n  id=\"sidebar-splitter\"\n  label=\"Sidebar\"\n  orientation=\"horizontal\"\n>\n  <:primary>One</:primary>\n  <:secondary>\n    <.split_pane\n      id=\"filter-splitter\"\n      label=\"Filters\"\n      orientation=\"vertical\"\n    >\n      <:primary>Two</:primary>\n      <:secondary>Three</:secondary>\n    </.split_pane>\n  </:secondary>\n</.split_pane>\n```","ref":"Doggo.Components.html#build_split_pane/1-usage"},{"type":"macro","title":"Doggo.Components.build_stack/1","doc":"Applies a vertical margin between the child elements.\n\n\n> #### Maturity: Refining {: .info}","ref":"Doggo.Components.html#build_stack/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_stack/1","doc":"Generate component with default options:\n\n    build_stack()","ref":"Doggo.Components.html#build_stack/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_stack/1","doc":"```elixir\n[\n  name: :stack,\n  base_class: \"stack\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2,\n  recursive_class: \"is-recursive\"\n]\n```","ref":"Doggo.Components.html#build_stack/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_stack/1","doc":"```heex\n<.stack>\n   some block \n   some other block \n</.stack>\n```\n\nTo apply a vertical margin on nested elements as well, set `recursive` to\n`true`.\n\n```heex\n<.stack recursive={true}>\n   \n     some nested block \n     another nested block \n   \n   some other block \n</.stack>\n```","ref":"Doggo.Components.html#build_stack/1-usage"},{"type":"macro","title":"Doggo.Components.build_steps/1","doc":"Renders a navigation for form steps.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_steps/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_steps/1","doc":"Generate component with default options:\n\n    build_steps()","ref":"Doggo.Components.html#build_steps/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_steps/1","doc":"```elixir\n[\n  name: :steps,\n  base_class: \"steps\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2,\n  current_class: \"is-current\",\n  completed_class: \"is-completed\",\n  upcoming_class: \"is-upcoming\",\n  visually_hidden_class: \"is-visually-hidden\"\n]\n```","ref":"Doggo.Components.html#build_steps/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_steps/1","doc":"With patch navigation:\n\n```heex\n<.steps current_step={0}>\n  <:step on_click={JS.patch(to: ~p\"/form/step/personal-information\")}>\n    Profile\n  </:step>\n  <:step on_click={JS.patch(to: ~p\"/form/step/delivery\")}>\n    Delivery\n  </:step>\n  <:step on_click={JS.patch(to: ~p\"/form/step/confirmation\")}>\n    Confirmation\n  </:step>\n</.steps>\n```\n\nWith push events:\n\n```heex\n<.steps current_step={0}>\n  <:step on_click={JS.push(\"go-to-step\", value: %{step: \"profile\"})}>\n    Profile\n  </:step>\n  <:step on_click={JS.push(\"go-to-step\", value: %{step: \"delivery\"})}>\n    Delivery\n  </:step>\n  <:step on_click={JS.push(\"go-to-step\", value: %{step: \"confirmation\"})}>\n    Confirmation\n  </:step>\n</.steps>\n```","ref":"Doggo.Components.html#build_steps/1-usage"},{"type":"macro","title":"Doggo.Components.build_switch/1","doc":"Renders a switch as a button.\n\nIf you want to render a switch as part of a form, use the `input/1` component\nwith the type `\"switch\"` instead.\n\nNote that this component only renders a button with a label, a state, and\n` ` with the class `switch-control`. You will need to style the switch\ncontrol span with CSS in order to give it the appearance of a switch.\n\n\n> #### Maturity: Experimental {: .info}","ref":"Doggo.Components.html#build_switch/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_switch/1","doc":"Generate component with default options:\n\n    build_switch()","ref":"Doggo.Components.html#build_switch/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_switch/1","doc":"```elixir\n[\n  name: :switch,\n  base_class: \"switch\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_switch/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_switch/1","doc":"```heex\n<.switch\n  label=\"Subscribe\"\n  checked={true}\n  phx-click=\"toggle-subscription\"\n/>\n```","ref":"Doggo.Components.html#build_switch/1-usage"},{"type":"macro","title":"Doggo.Components.build_tab_navigation/1","doc":"Renders navigation tabs.\n\nThis component is meant for tabs that link to a different view or live action.\nIf you want to render tabs that switch between in-page content panels, use\n`tabs/1` instead.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_tab_navigation/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_tab_navigation/1","doc":"Generate component with default options:\n\n    build_tab_navigation()","ref":"Doggo.Components.html#build_tab_navigation/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_tab_navigation/1","doc":"```elixir\n[\n  name: :tab_navigation,\n  base_class: \"tab-navigation\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_tab_navigation/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_tab_navigation/1","doc":"```heex\n<.tab_navigation current_value={@live_action}>\n  <:item\n    patch={~p\"/pets/#{@pet}\"}\n    value={[:show, :edit]}\n  >\n    Profile\n  </:item>\n  <:item\n    patch={~p\"/pets/#{@pet}/appointments\"}\n    value={:appointments}\n  >\n    Appointments\n  </:item>\n  <:item\n    patch={~p\"/pets/#{@pet}/messages\"}\n    value={:messages}\n  >\n    Messages\n  </:item>\n</.tab_navigation>\n```","ref":"Doggo.Components.html#build_tab_navigation/1-usage"},{"type":"macro","title":"Doggo.Components.build_table/1","doc":"Renders a simple table.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_table/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_table/1","doc":"Generate component with default options:\n\n    build_table()","ref":"Doggo.Components.html#build_table/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_table/1","doc":"```elixir\n[\n  name: :table,\n  base_class: \"table-container\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_table/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_table/1","doc":"```heex\n<.table id=\"pets\" rows={@pets}>\n  <:col :let={p} label=\"name\"><%= p.name %></:col>\n  <:col :let={p} label=\"age\"><%= p.age %></:col>\n</.table>\n```","ref":"Doggo.Components.html#build_table/1-usage"},{"type":"macro","title":"Doggo.Components.build_tabs/1","doc":"Renders tab panels.\n\nThis component is meant for tabs that toggle content panels within the page.\nIf you want to link to a different view or live action, use\n`tab_navigation/1` instead.\n\n\n> #### Maturity: Developing {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Roving tabindex\n> - Move focus with arrow keys\n>","ref":"Doggo.Components.html#build_tabs/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_tabs/1","doc":"Generate component with default options:\n\n    build_tabs()","ref":"Doggo.Components.html#build_tabs/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_tabs/1","doc":"```elixir\n[\n  name: :tabs,\n  base_class: \"tabs\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_tabs/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_tabs/1","doc":"```heex\n<.tabs id=\"dog-breed-profiles\" label=\"Dog Breed Profiles\">\n  <:panel label=\"Golden Retriever\">\n     \n      Friendly, intelligent, great with families. Origin: Scotland. Needs\n      regular exercise.\n     \n  </:panel>\n  <:panel label=\"Siberian Husky\">\n     \n      Energetic, outgoing, distinctive appearance. Origin: Northeast Asia.\n      Loves cold climates.\n     \n  </:panel>\n  <:panel label=\"Dachshund\">\n     \n      Playful, stubborn, small size. Origin: Germany. Enjoys sniffing games.\n     \n  </:panel>\n</.tabs>\n```","ref":"Doggo.Components.html#build_tabs/1-usage"},{"type":"macro","title":"Doggo.Components.build_tag/1","doc":"Renders a tag, typically used for displaying labels, categories, or keywords.\n\n\n> #### Maturity: Refining {: .info}","ref":"Doggo.Components.html#build_tag/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_tag/1","doc":"Generate component with default options:\n\n    build_tag()","ref":"Doggo.Components.html#build_tag/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_tag/1","doc":"```elixir\n[\n  name: :tag,\n  base_class: \"tag\",\n  modifiers: [\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"],\n    variant: [\n      values: [nil, \"primary\", \"secondary\", \"info\", \"success\", \"warning\",\n       \"danger\"],\n      default: nil\n    ],\n    shape: [values: [nil, \"pill\"], default: nil]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_tag/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_tag/1","doc":"```heex\n<.tag>Well-Trained</.tag>\n```\n\nWith icon:\n\n```heex\n<.tag>\n  Puppy\n  <.icon> </.icon>\n</.tag>\n```\n\nWith delete button:\n\n```heex\n<.tag>\n  High Energy\n  <.button\n    phx-click=\"remove-tag\"\n    phx-value-tag=\"high-energy\"\n    aria-label=\"Remove tag\"\n  >\n    <.icon> </.icon>\n  </.button>\n</.tag>\n```","ref":"Doggo.Components.html#build_tag/1-usage"},{"type":"macro","title":"Doggo.Components.build_time/1","doc":"Renders a `Time`, `DateTime`, or `NaiveDateTime` in a ` ` tag.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_time/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_time/1","doc":"Generate component with default options:\n\n    build_time()","ref":"Doggo.Components.html#build_time/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_time/1","doc":"```elixir\n[\n  name: :time,\n  base_class: nil,\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_time/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_time/1","doc":"By default, the given value is formatted for display with `to_string/1`. This:\n\n```heex\n \n```\n\nWill be rendered as:\n\n```html\n \n  12:22:06.003\n \n```\n\nYou can also pass a custom formatter function. For example, if you are using\n[ex_cldr_dates_times](https://hex.pm/packages/ex_cldr_dates_times) in your\napplication, you could do this:\n\n```heex\n \n```\n\nWhich, depending on your locale, may be rendered as:\n\n```html\n \n  14:22:06 PM\n \n```","ref":"Doggo.Components.html#build_time/1-usage"},{"type":"macro","title":"Doggo.Components.build_toggle_button/1","doc":"Renders a button that toggles a state.\n\nUse this component to switch a feature or setting on or off, for example to\ntoggle dark mode or mute/unmute sound.\n\nSee also `button/1`, `button_link/1`, and `disclosure_button/1`.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_toggle_button/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_toggle_button/1","doc":"Generate component with default options:\n\n    build_toggle_button()","ref":"Doggo.Components.html#build_toggle_button/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_toggle_button/1","doc":"```elixir\n[\n  name: :toggle_button,\n  base_class: \"button\",\n  modifiers: [\n    variant: [\n      values: [\"primary\", \"secondary\", \"info\", \"success\", \"warning\", \"danger\"],\n      default: \"primary\"\n    ],\n    size: [values: [\"small\", \"normal\", \"medium\", \"large\"], default: \"normal\"],\n    fill: [values: [\"solid\", \"outline\", \"text\"], default: \"solid\"],\n    shape: [values: [nil, \"circle\", \"pill\"], default: nil]\n  ],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_toggle_button/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_toggle_button/1","doc":"With a `Phoenix.LiveView.JS` command:\n\n```heex\n<.toggle_button on_click={JS.push(\"toggle-mute\")} pressed={@muted}>\n  Mute\n</.toggle_button>\n```","ref":"Doggo.Components.html#build_toggle_button/1-usage"},{"type":"macro","title":"Accessibility - Doggo.Components.build_toggle_button/1","doc":"The button state is conveyed via the `aria-pressed` attribute and the button\nstyling. The button text should not change depending on the state. You may\nhowever include an icon that changes depending on the state.","ref":"Doggo.Components.html#build_toggle_button/1-accessibility"},{"type":"macro","title":"CSS - Doggo.Components.build_toggle_button/1","doc":"A toggle button can be identified with an attribute selector for the\n`aria-pressed` attribute.\n\n```css\n// any toggle button regardless of state\nbutton[aria-pressed] {}\n\n// unpressed toggle buttons\nbutton[aria-pressed=\"false\"] {}\n\n// pressed toggle buttons\nbutton[aria-pressed=\"true\"] {}\n```","ref":"Doggo.Components.html#build_toggle_button/1-css"},{"type":"macro","title":"Doggo.Components.build_toolbar/1","doc":"Renders a container for a set of controls.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Roving tabindex\n> - Move focus with arrow keys\n>","ref":"Doggo.Components.html#build_toolbar/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_toolbar/1","doc":"Generate component with default options:\n\n    build_toolbar()","ref":"Doggo.Components.html#build_toolbar/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_toolbar/1","doc":"```elixir\n[\n  name: :toolbar,\n  base_class: \"toolbar\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_toolbar/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_toolbar/1","doc":"Direct children of this component can be any types buttons or groups of\nbuttons.\n\n```heex\n<.toolbar label=\"Actions for the dog\">\n   \n     \n      <.icon label=\"Feed dog\"> </.icon>\n     \n     \n      <.icon label=\"Walk dog\"> </.icon>\n     \n   \n   \n     \n      <.icon label=\"Teach a Trick\"> </.icon>\n     \n     \n      <.icon label=\"Groom dog\"> </.icon>\n     \n   \n</.toolbar>\n```","ref":"Doggo.Components.html#build_toolbar/1-usage"},{"type":"macro","title":"Doggo.Components.build_tooltip/1","doc":"Renders content with a tooltip.\n\nThere are different ways to render a tooltip. This component renders a ` `\nwith the `tooltip` role, which is hidden unless the element is hovered on or\nfocused. For example CSS for this kind of tooltip, refer to\n[ARIA: tooltip role](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/tooltip_role).\n\nA simpler alternative for styled text-only tooltips is to use a data attribute\nand the [`attr` CSS function](https://developer.mozilla.org/en-US/docs/Web/CSS/attr).\nDoggo does not provide a component for that kind of tooltip, since it is\ncontrolled by attributes only. You can check\n[Pico CSS](https://picocss.com/docs/tooltip) for an example implementation.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_tooltip/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_tooltip/1","doc":"Generate component with default options:\n\n    build_tooltip()","ref":"Doggo.Components.html#build_tooltip/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_tooltip/1","doc":"```elixir\n[\n  name: :tooltip,\n  base_class: \"tooltip-container\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_tooltip/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_tooltip/1","doc":"With an inline text:\n\n```heex\n \n  Did you know that the\n  <.tooltip id=\"labrador-info\">\n    Labrador Retriever\n    <:tooltip>\n        Labrador Retriever  \n       \n        Labradors are known for their friendly nature and excellent\n        swimming abilities.\n       \n    </:tooltip>\n  </.tooltip>\n  is one of the most popular dog breeds in the world?\n \n```\n\nIf the inner block contains a link, add the `:contains_link` attribute:\n\n```heex\n \n  Did you know that the\n  <.tooltip id=\"labrador-info\" contains_link>\n    <.link navigate={~p\"/labradors\"}>Labrador Retriever</.link>\n    <:tooltip>\n        Labrador Retriever  \n       \n        Labradors are known for their friendly nature and excellent\n        swimming abilities.\n       \n    </:tooltip>\n  </.tooltip>\n  is one of the most popular dog breeds in the world?\n \n```","ref":"Doggo.Components.html#build_tooltip/1-usage"},{"type":"macro","title":"Doggo.Components.build_tree/1","doc":"Renders a hierarchical list as a tree.\n\nA good use case for this component is a folder structure. For navigation and\nother menus, a regular nested list should be preferred.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing features**\n>\n> - Expand and collapse nodes\n> - Select nodes\n> - Navigate tree with arrow keys\n>","ref":"Doggo.Components.html#build_tree/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_tree/1","doc":"Generate component with default options:\n\n    build_tree()","ref":"Doggo.Components.html#build_tree/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_tree/1","doc":"```elixir\n[\n  name: :tree,\n  base_class: \"tree\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_tree/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_tree/1","doc":"```heex\n<.tree label=\"Dogs\">\n   \n    Breeds\n    <:items>\n      <.tree_item>Golden Retriever</.tree_item>\n      <.tree_item>Labrador Retriever</.tree_item>\n    </:items>\n  </.tree_item>\n  <.tree_item>\n    Characteristics\n    <:items>\n      <.tree_item>Playful</.tree_item>\n      <.tree_item>Loyal</.tree_item>\n    </:items>\n  </.tree_item>\n</.tree>\n```","ref":"Doggo.Components.html#build_tree/1-usage"},{"type":"macro","title":"CSS - Doggo.Components.build_tree/1","doc":"You can target the wrapper with an attribute selector for the role:\n\n```css\n[role=\"tree\"] {}\n```","ref":"Doggo.Components.html#build_tree/1-css"},{"type":"macro","title":"Doggo.Components.build_tree_item/1","doc":"Renders a tree item within a `tree/1`.\n\nThis component can be used as a direct child of `tree/1` or within the `items`\nslot of this component.\n\n\n> #### Maturity: Experimental {: .info}\n>\n> The necessary JavaScript for making this component fully functional and\n> accessible will be added in a future version.\n>\n> **Missing featumres**\n>\n> - Expand and collapse nodes\n> - Select nodes\n> - Navigate tree with arrow keys\n>","ref":"Doggo.Components.html#build_tree_item/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_tree_item/1","doc":"Generate component with default options:\n\n    build_tree_item()","ref":"Doggo.Components.html#build_tree_item/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_tree_item/1","doc":"```elixir\n[\n  name: :tree_item,\n  base_class: \"tree-item\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_tree_item/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_tree_item/1","doc":"```heex\n<.tree label=\"Dogs\">\n  <.tree_item>\n    Breeds\n    <:items>\n      <.tree_item>Golden Retriever</.tree_item>\n      <.tree_item>Labrador Retriever</.tree_item>\n    </:items>\n  </.tree_item>\n  <.tree_item>\n    Characteristics\n    <:items>\n      <.tree_item>Playful</.tree_item>\n      <.tree_item>Loyal</.tree_item>\n    </:items>\n  </.tree_item>\n</.tree>\n```\n\nIcons can be added before the label:\n\n<.tree_item>\n    Breeds\n  <:items>\n    <.tree_item>  Golden Retriever</.tree_item>\n    <.tree_item>  Labrador Retriever</.tree_item>\n  </:items>\n</.tree_item>","ref":"Doggo.Components.html#build_tree_item/1-usage"},{"type":"macro","title":"Doggo.Components.build_vertical_nav/1","doc":"Renders a vertical navigation menu.\n\nIt is commonly placed within drawers or sidebars.\n\nFor hierarchical menu structures, use `vertical_nav_nested/1` within the\n`:item` slot.\n\nTo include sections in your drawer or sidebar that are not part of the\nnavigation menu (like informational text or a site search), use the\n`vertical_nav_section/1` component.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_vertical_nav/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_vertical_nav/1","doc":"Generate component with default options:\n\n    build_vertical_nav()","ref":"Doggo.Components.html#build_vertical_nav/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_vertical_nav/1","doc":"```elixir\n[\n  name: :vertical_nav,\n  base_class: \"vertical-nav\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_vertical_nav/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_vertical_nav/1","doc":"```heex\n<.vertical_nav label=\"Main\">\n  <:item>\n    <.link navigate={~p\"/dashboard\"}>Dashboard</.link>\n  </:item>\n  <:item>\n    <.vertical_nav_nested>\n      <:title>Content</:title>\n      <:item current_page>\n        <.link navigate={~p\"/posts\"}>Posts</.link>\n      </:item>\n      <:item>\n        <.link navigate={~p\"/comments\"}>Comments</.link>\n      </:item>\n    </.vertical_nav_nested>\n  </:item>\n</.vertical_nav>\n```","ref":"Doggo.Components.html#build_vertical_nav/1-usage"},{"type":"macro","title":"Doggo.Components.build_vertical_nav_nested/1","doc":"Renders nested navigation items within the `:item` slot of the\n`vertical_nav/1` component.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_vertical_nav_nested/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_vertical_nav_nested/1","doc":"Generate component with default options:\n\n    build_vertical_nav_nested()","ref":"Doggo.Components.html#build_vertical_nav_nested/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_vertical_nav_nested/1","doc":"```elixir\n[\n  name: :vertical_nav_nested,\n  base_class: \"vertical-nav-nested\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_vertical_nav_nested/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_vertical_nav_nested/1","doc":"```heex\n<.vertical_nav label=\"Main\">\n  <:item>\n    <.vertical_nav_nested>\n      <:title>Content</:title>\n      <:item current_page>\n        <.link navigate={~p\"/posts\"}>Posts</.link>\n      </:item>\n      <:item>\n        <.link navigate={~p\"/comments\"}>Comments</.link>\n      </:item>\n    </.vertical_nav_nested>\n  </:item>\n</.vertical_nav>\n```","ref":"Doggo.Components.html#build_vertical_nav_nested/1-usage"},{"type":"macro","title":"Doggo.Components.build_vertical_nav_section/1","doc":"Renders a section within a sidebar or drawer that contains one or more\nitems which are not navigation links.\n\nTo render navigation links, use `vertical_nav/1` instead.\n\n\n> #### Maturity: Developing {: .info}","ref":"Doggo.Components.html#build_vertical_nav_section/1"},{"type":"macro","title":"Generate Component - Doggo.Components.build_vertical_nav_section/1","doc":"Generate component with default options:\n\n    build_vertical_nav_section()","ref":"Doggo.Components.html#build_vertical_nav_section/1-generate-component"},{"type":"macro","title":"Default options - Doggo.Components.build_vertical_nav_section/1","doc":"```elixir\n[\n  name: :vertical_nav_section,\n  base_class: \"vertical-nav-section\",\n  modifiers: [],\n  class_name_fun: &Doggo.modifier_class_name/2\n]\n```","ref":"Doggo.Components.html#build_vertical_nav_section/1-default-options"},{"type":"macro","title":"Usage - Doggo.Components.build_vertical_nav_section/1","doc":"```heex\n<.vertical_nav_section>\n  <:title>Search</:title>\n  <:item> </:item>\n</.vertical_nav_section>\n```","ref":"Doggo.Components.html#build_vertical_nav_section/1-usage"},{"type":"module","title":"Doggo.Storybook","doc":"Generates [Phoenix Storybook](https://hex.pm/packages/phoenix_storybook)\nstories for the Doggo components.","ref":"Doggo.Storybook.html"},{"type":"module","title":"Usage - Doggo.Storybook","doc":"In your story module, use `Doggo.Storybook` and pass the name of the module\nin which you call the `Doggo.Components` macros and the name of the component\n(not the macro name).\n\n    defmodule Storybook.Components.Accordion do\n      use PhoenixStorybook.Story, :component\n      use Doggo.Storybook, module: MyAppWeb.CoreComponents, name: :accordion\n    end\n\nYou can automatically generate story modules for all configured components\nwith `mix dog.gen.stories`.","ref":"Doggo.Storybook.html#module-usage"},{"type":"task","title":"mix dog.gen.stories","doc":"Generates Phoenix Storybook modules for all configured components.","ref":"Mix.Tasks.Dog.Gen.Stories.html"},{"type":"task","title":"Usage - mix dog.gen.stories","doc":"Write stories for all configured components:\n\n    mix dog.gen.stories -m MyAppWeb.CoreComponents -o storybook -a\n\nWrite the story for a single component:\n\n    mix dog.gen.stories -m MyAppWeb.CoreComponents -o storybook -c button","ref":"Mix.Tasks.Dog.Gen.Stories.html#module-usage"},{"type":"task","title":"Options - mix dog.gen.stories","doc":"- -m, --module: The module where the Doggo components are compiled.\n- -o, --output: The Storybook folder.\n- -c, --component: The name of the component.\n- -a, --all: Write stories for all configured components.\n- -f, --force: Force folder creation and overwrite existing stories.","ref":"Mix.Tasks.Dog.Gen.Stories.html#module-options"},{"type":"task","title":"mix dog.modifiers","doc":"Returns a list of all modifier classes.","ref":"Mix.Tasks.Dog.Modifiers.html"},{"type":"task","title":"Usage - mix dog.modifiers","doc":"List modifier classes:\n\n    mix dog.modifiers\n\nWrite modifier classes to file:\n\n    mix dog.modifiers -m MyAppWeb.CoreComponents -o assets/modifiers.txt","ref":"Mix.Tasks.Dog.Modifiers.html#module-usage"},{"type":"extras","title":"Doggo","doc":"# Doggo\n\n[![Hex](https://img.shields.io/hexpm/v/doggo)](https://hex.pm/packages/doggo) ![CI](https://github.com/woylie/doggo/workflows/CI/badge.svg) [![Coverage Status](https://coveralls.io/repos/github/woylie/doggo/badge.svg)](https://coveralls.io/github/woylie/doggo)\n\n \n\nHeadless UI component collection for Phoenix, focused on semantics and\naccessibility.\n\nFor a full list of available components, please refer to the\n[documentation](https://hexdocs.pm/doggo/Doggo.html).","ref":"readme.html"},{"type":"extras","title":"Installation - Doggo","doc":"The package can be installed by adding `doggo` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:doggo, \"~> 0.6.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Doggo","doc":"Use `Doggo.Components` in your core components module or in a separate module.\n`Doggo.Components` defines macros that generate Phoenix components.\n\n```elixir\ndefmodule MyAppWeb.CoreComponents do\n  use Doggo.Components\n  use Phoenix.Component\n\n  build_alert()\n  build_alert_dialog()\n\n  build_button(\n    modifiers: [\n      size: [values: [\"normal\", \"small\"], default: \"normal\"]\n    ]\n  )\nend\n```\n\nEach modifier results in an additional attribute that is translated into a CSS\nclass. You can use the button defined above like this:\n\n```html\n<.button size=\"small\">Edit</.button>\n```\n\nMost of the components have a base class that matches the component name.\nBy default, `Doggo.modifier_class_name/2` is used to build the CSS class name\nfor modifier attributes. The button above would be rendered with the class\n`\"button is-small\"`.\n\nYou can override both the base class and the modifier class function:\n\n```elixir\ndefmodule MyAppWeb.CoreComponents do\n  use Doggo.Components\n  use Phoenix.Component\n\n  build_button(\n    base_class: \"alt-button\",\n    modifiers: [small: [size: [\"normal\", \"small\"], default: \"normal\"]],\n    class_name_fun: &MyAppWeb.CoreComponents.modifier_class/2\n  )\n\n  def modifier_class(name, value) do\n    \"#{name} #{value}\"\n  end\nend\n```\n\nWith these changes, the class would now be `\"alt-button size-small`. To remove\nthe base class, just set it to `nil`.\n\nIt is also possible to change the name of the generated component, which can be\nuseful if you want to compile multiple variants of the same component, or if\nyour design system uses different names.\n\n```elixir\nbuild_button(name: :alt_button, base_class: \"alt-button\")\n```\n\nThis button could be used with:\n\n```elixir\n<.alt_button>Edit \n```\n\nRefer to the `Doggo.Components` module documentation for more information about\nthe options and the individual components.","ref":"readme.html#usage"},{"type":"extras","title":"Storybook - Doggo","doc":"Doggo can generate\n[Phoenix Storybook](https://hex.pm/packages/phoenix_storybook) stories for the\ngenerated components. After you followed the installation instructions of\nPhoenix Storybook, you can run a mix task to generate the stories:\n\n```bash\nmix dog.gen.stories -m MyAppWeb.CoreComponents -o storybook --all\n```\n\nHere, `MyAppWeb.CoreComponents` is the module in which you added\n`use Doggo.Components`, and `storybook` is the path to the storybook folder.\n\nThe task will only generate story modules for the components that you\nconfigured. The stories will include variations for all configured modifiers.\n\nYou don't need to update the stories after changing the modifiers of a\ncomponent. However, you'll need to run the task again after adding new\ncomponents to your module, or potentially after a new Doggo version was\nreleased.\n\nThe task will ask for confirmation to overwrite existing stories. To only\nwrite the story for a single component, you can run:\n\n```bash\nmix dog.gen.stories -m MyAppWeb.CoreComponents -o storybook -c button\n```","ref":"readme.html#storybook"},{"type":"extras","title":"PurgeCSS - Doggo","doc":"If you use PurgeCSS, you will need to add `deps/doggo/lib/doggo.ex` to your\nPurgeCSS configuration.\n\nDoggo also uses modifier CSS classes to alter the appearance of components. The\nclass names are generated dynamically, which means PurgeCSS won't be able to\nfind them in the source code. You can use `mix dog.modifiers` to save a\nlist of all modifier class names to a file:\n\n```bash\nmix dog.modifiers -m MyAppWeb.CoreComponents -o assets/modifiers.txt\n```\n\nAdd the generated file to your PurgeCSS configuration as well.","ref":"readme.html#purgecss"},{"type":"extras","title":"Design decisions - Doggo","doc":"- Favor semantic HTML elements over CSS classes for structure and clarity.\n- Adhere to accessibility guidelines with appropriate ARIA attributes and roles.\n- Utilize semantic HTML and ARIA attributes for style bindings to states, rather\n  than relying on CSS classes.\n- Where state or variations can not be expressed semantically, use modifier\n  classes named `.is-*` or `.has-*`.\n- The library is designed without default styles and does not prefer any\n  particular CSS framework.","ref":"readme.html#design-decisions"},{"type":"extras","title":"Demo app - Doggo","doc":"The repository contains a demo application that renders the plain storybook.\nNote that it doesn't come with any CSS, so all components will be rendered with\ndefault browser styles.\n\n```bash\ngit clone git@github.com:woylie/doggo.git\ncd doggo/demo\nmix setup\nmix phx.server\n```\n\nThe storybook can be accessed at http://localhost:4000.","ref":"readme.html#demo-app"},{"type":"extras","title":"Status - Doggo","doc":"The library is actively developed. Being in its early stages, the library may\nstill undergo significant changes, including potential breaking changes.","ref":"readme.html#status"},{"type":"extras","title":"Maturity Levels - Doggo","doc":"Each component in the library is marked with one of four maturity levels.\n\n- **Experimental**: These components are in the early development phase. They\n  are incomplete, have unstable APIs, and are subject to significant changes.\n  Not recommended for production use.\n- **Developing**: Components at this stage have complete semantics, but\n  interactivity features may still be missing. The API may still change based on\n  feedback and testing. Suitable for internal testing and early feedback.\n- **Refining**: Feature-complete components with a stable API, full\n  configurability, and all required keyboard interactivity for accessibility\n  implemented. The focus is on identifying and fixing remaining issues. Suitable\n  for broader testing and cautious production use.\n- **Stable**: Fully developed, tested, and ready for production use. These\n  components have a stable API, are fully interactive, include a complete\n  storybook module, and have exemplary CSS styles defined.","ref":"readme.html#maturity-levels"},{"type":"extras","title":"Feedback - Doggo","doc":"If you encounter any issues with a component, have suggestions for improvements,\nor need a component for a specific use case that isn't currently available,\nplease don't hesitate to open a\n[Github issue](https://github.com/woylie/doggo/issues).","ref":"readme.html#feedback"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"## [0.6.0] - 2024-07-23","ref":"changelog.html#unreleased"},{"type":"extras","title":"Added - Changelog","doc":"- Add `Doggo.Storybook` and `mix dog.gen.stories` for generating\n  `Phoenix.Storybook` stories for the configured components. The generated\n  stories automatically render variation groups for all configured modifiers.\n- Add `Doggo.modifier_classes/1`.\n- Add `Doggo.modifier_class_name/2`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Replace all function components defined in `Doggo` with build macros\n  in `Doggo.Components`. This allows you to customize the modifier attributes,\n  component names, base classes, and some other options at compile time.\n- Make modifier class name builder configurable.\n- Rename build macro for former `input` component to `field`.\n- Configure `Gettext` module for `field` component (formerly `input`) via\n  compile-time option instead of global attribute.\n- Allow to set required text and required title attributes for input and label.\n- Add `module` argument to `mix dog.modifiers` that points to the module\n  in which the Doggo components are configured.\n- Replace `placeholder` attribute with `placeholder_src` and\n  `placeholder_content` attributes in `avatar` component.\n- Replace `phx-feedback-for` attribute in favor of\n  `Phoenix.Component.used_input?/1`.\n- Don't use `h2` for `Doggo.page_header/1` sub title.\n- Nest `vertical_nav_nested` component into ` `.\n- Rename `drawer-nav-title` class in `vertical_nav_nested` component to be\n  based on configured component name (default: `vertical-nav-nested-title`).\n- Better consistency, various improvements and optimizations in all components.\n- Revise The component type classification.\n- Add maturity levels for all components (experimental, developing, refining,\n  stable).\n- Require `live_view ~> 1.0.0-rc.6`.","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Changelog","doc":"- Remove `Phoenix.Storybook` stories bundled in the `priv` folder in favor of\n  `mix dog.gen.stories` and `Doggo.Storybook`.\n- Remove `Doggo.flash_group/1`.","ref":"changelog.html#removed"},{"type":"extras","title":"Upgrade Guide - Changelog","doc":"1. For all Doggo components you were using, call the corresponding `build`\n   macros in `Doggo.Components` in one of your modules and update your HEEx\n   templates to call the generated functions instead of the ones from the\n   `Doggo` module. See readme for installation details.\n2. The previous Doggo version instructed you to configure a separate Storybook\n   that reads the stories from the `priv` folder of the dependency. Remove that\n   second Storybook and run\n   `mix dog.gen.stories -m [component-module] -o [storybook-folder] -a` to\n   generate stories for the configured Doggo components in the primary\n   Storybook.\n3. If you use `mix dog.modifiers` in a script, add the `--module` argument.\n4. If you were setting the `gettext` attribute on the `input` component, pass\n   the `gettext_module` option to `Doggo.Components.build_field/1` instead.\n\n## [0.5.0] - 2024-02-12","ref":"changelog.html#upgrade-guide"},{"type":"extras","title":"Added - Changelog","doc":"- New component: `Doggo.alert_dialog/1`.\n- New component: `Doggo.carousel/1`.\n- New component: `Doggo.combobox/1`.\n- New component: `Doggo.disclosure_button/1`.\n- New component: `Doggo.menu/1`.\n- New component: `Doggo.menu_bar/1`.\n- New component: `Doggo.menu_button/1`.\n- New component: `Doggo.menu_group/1`.\n- New component: `Doggo.menu_item/1`.\n- New component: `Doggo.menu_item_checkbox/1`.\n- New component: `Doggo.menu_item_radio_group/1`.\n- New component: `Doggo.radio_group/1`.\n- New component: `Doggo.split_pane/1`.\n- New component: `Doggo.tabs/1`.\n- New component: `Doggo.toolbar/1`.\n- New component: `Doggo.tree/1`.\n- Storybook page about modifier classes.\n- Mix task `mix dog.modifiers` to list all modifier classes.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Set `aria-invalid` and `aria-errormessage` attributes in `Doggo.input/1`\n  component.\n- Use buttons instead of links in `Doggo.action_bar/1`.\n- Add `toolbar` role to `Doggo.action_bar/1`.\n- Use `section` instead of `article` in `Doggo.modal/1`.\n- Use `button` for close button in `Doggo.modal/1`.\n- Add `dismissable` attribute to `Doggo.modal/1`.\n- Remove `role` from `button_link/1`, add `class`.\n- Rename `Doggo.drawer/1` slots to `header`, `main`, and `footer`.\n- Rename `Doggo.drawer_nav/1`, `Doggo.drawer_nav_nested/1` and\n  `Doggo.drawer_nav_section` to `Doggo.vertical_nav/1`,\n  `Doggo.vertical_nav_nested/1` and `Doggo.vertical_nav_section/1`.\n- Depend on `phoenix_storybook ~> 0.6.0`.\n\n## [0.4.0] - 2023-12-31","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- New component: `Doggo.cluster/1`.\n- New component: `Doggo.toggle_button/1`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Significant changes to `Doggo.alert/1` and `Doggo.flash_group/1`.\n- Require `id` attribute for `Doggo.callout/1`.\n- Add `:normal` as size for `Doggo.icon_sprite/1`.\n- Remove `:error` variant in favor of `:danger`.\n- Add ` ` around text placeholder for `Doggo.avatar/1`.\n- Add base class to `Doggo.image/1`, add `class` attribute.\n- Rename `Doggo.frame/1` ratio classes from `x-to-x` to `x-by-x`.\n- Add required `label` attribute to `Doggo.navbar/1`.\n- Add `class` attribute to `:item` slot of `Doggo.navbar_items/1`.\n- Add `required_title` attribute to `Doggo.label/1`.\n- Change `description` attribute of `Doggo.field_description/1` to inner block.\n- Require `id` attribute for `Doggo.drawer_section/1`.\n- Add `aria-labelledby` attribute to `Doggo.drawer_section/1`.\n- Require `id` and `label` attributes for `Doggo.drawer_nav/1`.\n- Add `class` attribute to `Doggo.drawer_nav` item slot.\n- Require `id` attribute for `Doggo.drawer_nested_nav/1`.\n- Add `class` attribute to `Doggo.drawer_nested_nav` item slot.\n- Add `close_label` attribute to `Doggo.modal/1`.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Box header not rendered if only action slot is used without banner or title.\n- Aria label of breadcrumb component not overridable.\n- Radio groups and checkbox groups always marked as required.\n- Missing datalist option text.\n\n## [0.3.1] - 2023-12-28","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Allow event name as string in `on_click` attributes of app bar and steps.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Faulty application of the `on_click` attribute in `Doggo.steps/1`.\n\n## [0.3.0] - 2023-12-27","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- New component: `Doggo.avatar/1`.\n- New component: `Doggo.badge/1`.\n- New component: `Doggo.bottom_navigation/1`.\n- New component: `Doggo.box/1`.\n- New component: `Doggo.callout/1`.\n- New component: `Doggo.fab/1`.\n- New component: `Doggo.field_group/1`.\n- New component: `Doggo.page_header/1`.\n- New component: `Doggo.skeleton/1`.\n- New component: `Doggo.steps/1`.\n- New component: `Doggo.tag/1`.\n- New component: `Doggo.tooltip/1`.\n- Allow to visually hide labels.\n- Support autocomplete via ` ` in `input/1` component.\n- `addon_left` and `addon_right` slots on the `input/1` component.\n- `gettext` attribute on `Doggo.input/1`, giving you the choice to\n  set the Gettext module locally.\n\n## [0.2.1] - 2023-12-19","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Ensure compatibility with Phoenix.HTML 4.0.\n\n## [0.2.0] - 2023-12-17","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- New `tab_navigation/1` component.\n- New `frame/1` component.\n- New `image/1` component.\n\n## [0.1.5] - 2023-12-16","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Remove default value for `errors` attribute on `input` component.\n\n## [0.1.4] - 2023-12-16","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Added storybook stories for the remaining components.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Errors passed as an attribute to the `input/1` component were overridden.\n- The `field_description/1` component had a stray ` ` tag.\n\n## [0.1.3] - 2023-12-15","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Added `priv/storybook` folder to package configuration.\n\n## [0.1.2] - 2023-12-14","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Added more storybook stories.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed attribute name for table rows.\n\n## [0.1.1] - 2023-12-13","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Storybook stories for more components and documentation improvements.\n\n## [0.1.0] - 2023-12-13\n\nInitial release.","ref":"changelog.html#changed"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}